--
-- Local Variables and Constants
--

--local addonName = ...
--local addon = _G[addonName]
local _L = SetCollectorLocalization

local WOW_VERSION = select(4,GetBuildInfo())
local DB_VERSION = WOW_VERSION

local ANY					=	{ Code = "Z", Description = "Any" }

local DEATHKNIGHT = { Code = "DK", Description = "DEATHKNIGHT" }
local DRUID 			= { Code = "DR", Description = "DRUID" }
local HUNTER 			= { Code = "HU", Description = "HUNTER" }
local MAGE 				= { Code = "MA", Description = "MAGE" }
local MONK 				= { Code = "MO", Description = "MONK" }
local PALADIN 		= { Code = "PA", Description = "PALADIN" }
local PRIEST 			= { Code = "PR", Description = "PRIEST" }
local ROGUE 			= { Code = "RO", Description = "ROGUE" }
local SHAMAN 			= { Code = "SH", Description = "SHAMAN" }
local WARLOCK 		= { Code = "WK", Description = "WARLOCK" }
local WARRIOR 		= { Code = "WR", Description = "WARRIOR" }

local ALLIANCE 		= { Code = "A", Description = "Alliance" }
local HORDE 			= { Code = "H", Description = "Horde" }

local TANK 				= { Code = "T", Description = "TANK" }
local HEALER 			= { Code = "H", Description = "HEALER" }
local CASTER 			= { Code = "C", Description = "CASTER" }
local RANGED 			= { Code = "R", Description = "RANGED" }
local MELEE 			= { Code = "M", Description = "MELEE" }

local POOR 			= 0
local COMMON 		= 1
local UNCOMMON 	= 2
local RARE 			= 3
local EPIC 			= 4
local LEGENDARY = 5
local ARTIFACT 	= 6
local HEIRLOOM 	= 7

-- Collection Types
local LEGENDARY 	= { ID = 1, Code = "ZZ", Description = "LEGENDARY" }
local RAID 				= { ID = 2, Code = "TR", Description = "RAID" }
local DUNGEON 		= { ID = 3, Code = "DG", Description = "DUNGEON" }
local CHALLENGE 	= { ID = 4, Code = "CD", Description = "CHALLENGE" }
local PVP 				= { ID = 5, Code = "PV", Description = "PVP" }
local HOLIDAY			= { ID = 6, Code = "HO", Description = "HOLIDAY" }

--
-- Helper Functions
--

local function GetCount(T)
  local count = 0
  for _ in pairs(T) do count = count + 1 end
  return count
end

local function CreateCollections(version, release)
	SetCollectorDB = {
		[LEGENDARY.ID] 	= { Title = LEGENDARY.Description, Sets = { } },
		[RAID.ID] 			= { Title = RAID.Description, Sets = { } },
		[DUNGEON.ID] 		= { Title = DUNGEON.Description, Sets = { } },
		[CHALLENGE.ID] 	= { Title = CHALLENGE.Description, Sets = { } },
		[PVP.ID] 				= { Title = PVP.Description, Sets = { } },
		[HOLIDAY.ID] 		= { Title = HOLIDAY.Description, Sets = { } },
		version = version,
		release = release
	}
	--print(version)
	--print(release)
end

local function AddSet(minVersion, maxVersion, collection, id, title, class, role, faction, ...)
	if WOW_VERSION >= minVersion then
		if maxVersion == nil or WOW_VERSION <= maxVersion then
			local tempSet = { }
			tempSet = {
				Title = title,
				Class = class.Description,
				Role = role.Description,
				Faction = faction.Description,
				Name = name,
				Variants = { }
			}
			local ID = collection.Code..string.format("%03d", id)..class.Code..role.Code..faction.Code
			SetCollectorDB[collection.ID].Sets[ID] = tempSet
			return ID
		end
	end
end

local function AddVariant(minVersion, maxVersion, collection, set, title, ...)
	if WOW_VERSION >= minVersion then
		if maxVersion == nil or WOW_VERSION <= maxVersion then
			local tempItems = { }
			local n = select("#",...)
			for i = 1,n do
				local v = select(i,...)
				tinsert(tempItems,v)
			end
			local tempVariant = {
				Title = title,
				Items = tempItems,
				Count = #tempItems
			}
			tinsert(SetCollectorDB[collection.ID].Sets[set].Variants, tempVariant)	
		end
	end	
end

local function T17(itemID, bonusID)
	local itemString = ""
	if itemID ~= nil and bonusID ~= nil then
		itemString = "item:"..itemID..":0:0:0:0:0:0:0:0:0:491:1:"..bonusID
	else
		itemString = itemID
	end
	return itemString
end

--
-- Class Functions 
--

local function AddDeathKnightSets()
	local set = ""
	
	-- Legendaries
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",17182)
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",32837)
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",49623)
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_STR_90",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_STR_90",102249)
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_STR_90",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_STR_90",102250)
	
	-- Raid Tier Sets
	set = AddSet(60000,nil,RAID,17,"DK_TR_17",DEATHKNIGHT,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115539,115536,115537,115538,115535)	-- No Bonus
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115539,566),T17(115536,566),T17(115537,566),T17(115538,566),T17(115535,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115539,567),T17(115536,567),T17(115537,567),T17(115538,567),T17(115535,567))
	
	set = AddSet(50400,nil,RAID,16,"DK_TR_MELEE_16",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99057,99059,99066,99067,99058)
				AddVariant(60000,nil,RAID,set,"NORMAL",99571,99639,99608,99609,99572)
				AddVariant(60000,nil,RAID,set,"HEROIC",99194,99187,99192,99193,99186)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99337,99339,99335,99336,99338)
	
	set = AddSet(50400,nil,RAID,16,"DK_TR_TANK_16",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99049,99040,99060,99048,99039)
				AddVariant(60000,nil,RAID,set,"NORMAL",99605,99652,99640,99604,99564)
				AddVariant(60000,nil,RAID,set,"HEROIC",99190,99179,99188,99189,99191)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99323,99325,99330,99331,99324)

	set = AddSet(50400,nil,RAID,15,"DK_TR_TANK_15",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95827,95829,95825,95826,95828)
				AddVariant(50400,nil,RAID,set,"NORMAL",95227,95229,95225,95226,95228)
				AddVariant(50400,nil,RAID,set,"HEROIC",96571,96573,96569,96570,96572)

	set = AddSet(50400,nil,RAID,15,"DK_TR_MELEE_15",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95832,95834,95830,95831,95833)
				AddVariant(50400,nil,RAID,set,"NORMAL",95232,95234,95230,95231,95233)
				AddVariant(50400,nil,RAID,set,"HEROIC",96576,96578,96574,96575,96577)
	
	set = AddSet(50400,nil,RAID,14,"DK_TR_TANK_14",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86656,86654,86658,86657,86655)
				AddVariant(50400,nil,RAID,set,"NORMAL",85316,85314,85318,85317,85315)
				AddVariant(50400,nil,RAID,set,"HEROIC",86920,86922,86918,86919,86921)
	
	set = AddSet(50400,nil,RAID,14,"DK_TR_MELEE_14",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86676,86674,86678,86677,86675)
				AddVariant(50400,nil,RAID,set,"NORMAL",85336,85334,85338,85337,85335)
				AddVariant(50400,nil,RAID,set,"HEROIC",86915,86917,86913,86914,86916)

	set = AddSet(50400,nil,RAID,13,"DK_TR_TANK_13",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78792,78846,78758,78773,78811)
				AddVariant(50400,nil,RAID,set,"NORMAL",77010,77012,77008,77009,77011)
				AddVariant(50400,nil,RAID,set,"HEROIC",78697,78751,78663,78678,78716)

	set = AddSet(50400,nil,RAID,13,"DK_TR_MELEE_13",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78782,78831,78754,78765,78802)
				AddVariant(50400,nil,RAID,set,"NORMAL",76976,76978,76974,76975,76977)
				AddVariant(50400,nil,RAID,set,"HEROIC",78687,78736,78659,78670,78707)
	
	set = AddSet(50400,nil,RAID,12,"DK_TR_TANK_12",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",70954,70951,70955,70953,70952)
				AddVariant(50400,nil,RAID,set,"HEROIC",71483,71485,71481,71482,71484)

	set = AddSet(50400,nil,RAID,12,"DK_TR_MELEE_12",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71060,71062,71058,71059,71061)
				AddVariant(50400,nil,RAID,set,"HEROIC",71478,71480,71476,71477,71479)
	
	set = AddSet(50400,nil,RAID,11,"DK_TR_TANK_11",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60351,60353,60349,60350,60352)
				AddVariant(50400,nil,RAID,set,"HEROIC",65186,65188,65184,65185,65187)

	set = AddSet(50400,nil,RAID,11,"DK_TR_MELEE_11",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60341,60343,60339,60340,60342)
				AddVariant(50400,nil,RAID,set,"HEROIC",65181,65183,65179,65180,65182)
	
	set = AddSet(50400,nil,RAID,10,"DK_TR_TANK_10",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50855,50853,50857,50856,50854)
				AddVariant(50400,nil,RAID,set,"NORMAL",51133,51130,51134,51132,51131)
				AddVariant(50400,nil,RAID,set,"HEROIC",51306,51309,51305,51307,51308)

	set = AddSet(50400,nil,RAID,10,"DK_TR_MELEE_10",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50096,50098,50094,50095,50097)
				AddVariant(50400,nil,RAID,set,"NORMAL",51127,51125,51129,51128,51126)
				AddVariant(50400,nil,RAID,set,"HEROIC",51312,51314,51310,51311,51313)
	
	set = AddSet(50400,nil,RAID,9,"DK_TR_TANK_A_09",DEATHKNIGHT,TANK,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48529,48535,48531,48537,48533)
				AddVariant(50400,nil,RAID,set,"NORMAL",48540,48542,48538,48539,48541)
				AddVariant(50400,nil,RAID,set,"HEROIC",48545,48543,48547,48546,48544)

	set = AddSet(50400,nil,RAID,9,"DK_TR_MELEE_A_09",DEATHKNIGHT,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48472,48478,48474,48480,48476)
				AddVariant(50400,nil,RAID,set,"NORMAL",48483,48485,48481,48482,48484)
				AddVariant(50400,nil,RAID,set,"HEROIC",48488,48486,48490,48489,48487)

	set = AddSet(50400,nil,RAID,9,"DK_TR_TANK_H_09",DEATHKNIGHT,TANK,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48560,48562,48558,48559,48561)
				AddVariant(50400,nil,RAID,set,"NORMAL",48555,48553,48557,48556,48554)
				AddVariant(50400,nil,RAID,set,"HEROIC",48550,48552,48548,48549,48551)
	
	set = AddSet(50400,nil,RAID,9,"DK_TR_MELEE_H_09",DEATHKNIGHT,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48503,48505,48501,48502,48504)
				AddVariant(50400,nil,RAID,set,"NORMAL",48498,48496,48500,48499,48497)
				AddVariant(50400,nil,RAID,set,"HEROIC",48493,48495,48491,48492,48494)
	
	set = AddSet(50400,nil,RAID,8,"DK_TR_TANK_08",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45336,45339,45335,45337,45338)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46120,46122,46118,46119,46121)

	set = AddSet(50400,nil,RAID,8,"DK_TR_MELEE_08",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45342,45344,45340,45341,45343)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46115,46117,46111,46113,46116)

	set = AddSet(50400,nil,RAID,7,"DK_TR_TANK_07",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39625,39627,39623,39624,39626)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40565,40568,40559,40563,40567)

	set = AddSet(50400,nil,RAID,7,"DK_TR_MELEE_07",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39619,39621,39617,39618,39620)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40554,40557,40550,40552,40556)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"DK_CD_90",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"DK_CD_90",90053,90055,90051,90056,90052,90049,90054,90050)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,1,"DG_PLATE_03",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_PLATE_03",28225,27771,28403,27497,27870)
				
	-- PvP
	set = AddSet(50400,nil,PVP,160,"DK_PVP_16",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",115199,115201,115197,115198,115200)
				AddVariant(50400,nil,PVP,set,"COMBATANT",115051,115053,115049,115050,115052)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",115631,115633,115629,115630,115632)
				
	set = AddSet(50400,nil,PVP,160,"DK_PVP_16",DEATHKNIGHT,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",119976,119978,119974,119975,119977)
				AddVariant(50400,nil,PVP,set,"COMBATANT",119841,119843,119839,119840,119842)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",111104,111106,111102,111103,111105)
				
	set = AddSet(50400,nil,PVP,150,"DK_PVP_MELEE_15",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102713,102652,102676,102650,102651)
				AddVariant(50400,nil,PVP,set,"ELITE",103006,103008,103004,103005,103073,103007,103076)
				
	set = AddSet(50400,nil,PVP,150,"DK_PVP_MELEE_15",DEATHKNIGHT,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103379,103377,103378,103376,103380)
				AddVariant(50400,nil,PVP,set,"ELITE",103006,103008,103004,103005,103073,103007,103076)
				
	set = AddSet(50400,nil,PVP,140,"DK_PVP_MELEE_14",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100247,100251,100243,100245,100249)
				AddVariant(50400,nil,PVP,set,"ELITE",100248,100252,100244,100246,100250)
				
	set = AddSet(50400,nil,PVP,140,"DK_PVP_MELEE_14",DEATHKNIGHT,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100659,100596,100622,100594,100595)
				AddVariant(50400,nil,PVP,set,"ELITE",100248,100252,100244,100246,100250)
				
end

local function AddDruidSets()
	local set = 0
	
	-- Legendaries
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",DRUID,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",102246)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",DRUID,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",102248)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_AGI_90",DRUID,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_AGI_90",102245)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",DRUID,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",102247)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",DRUID,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",71086)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",DRUID,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",46017)
				
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",DRUID,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",17182)
	
	-- Raid Tier Sets
	set = AddSet(60000,nil,RAID,17,"DR_TR_17",DRUID,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115542,115544,115540,115541,115543)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115542,566),T17(115544,566),T17(115540,566),T17(115541,566),T17(115543,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115542,567),T17(115544,567),T17(115540,567),T17(115541,567),T17(115543,567))
	
	set = AddSet(50400,nil,RAID,16,"DR_TR_CASTER_16",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",98995,98998,98997,98994,98996)
				AddVariant(60000,nil,RAID,set,"NORMAL",99618,99621,99620,99617,99619)
				AddVariant(60000,nil,RAID,set,"HEROIC",99175,99169,99177,99174,99176)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99433,99428,99427,99432,99434)

	set = AddSet(50400,nil,RAID,16,"DR_TR_MELEE_16",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99043,99022,99041,99042,99044)
				AddVariant(60000,nil,RAID,set,"NORMAL",99599,99589,99632,99633,99600)
				AddVariant(60000,nil,RAID,set,"HEROIC",99182,99184,99180,99181,99183)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99328,99322,99326,99327,99329)

	set = AddSet(50400,nil,RAID,16,"DR_TR_TANK_16",DRUID,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99001,98978,98999,99000,98981)
				AddVariant(60000,nil,RAID,set,"NORMAL",99624,99664,99622,99623,99610)
				AddVariant(60000,nil,RAID,set,"HEROIC",99164,99166,99170,99163,99165)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99421,99423,99419,99420,99422)

	set = AddSet(50400,nil,RAID,16,"DR_TR_HEALER_16",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99013,99016,99015,99012,99014)
				AddVariant(60000,nil,RAID,set,"NORMAL",99638,99583,99582,99637,99581)
				AddVariant(60000,nil,RAID,set,"HEROIC",99178,99173,99172,99185,99171)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99436,99431,99430,99435,99429)

	set = AddSet(50400,nil,RAID,15,"DR_TR_CASTER_15",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95846,95849,95848,95845,95847)
				AddVariant(50400,nil,RAID,set,"NORMAL",95246,95249,95248,95245,95247)
				AddVariant(50400,nil,RAID,set,"HEROIC",96590,96593,96592,96589,96591)

	set = AddSet(50400,nil,RAID,15,"DR_TR_MELEE_15",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95837,95839,95835,95836,95838)
				AddVariant(50400,nil,RAID,set,"NORMAL",95237,95239,95235,95236,95238)
				AddVariant(50400,nil,RAID,set,"HEROIC",96581,96583,96579,96580,96582)

	set = AddSet(50400,nil,RAID,15,"DR_TR_TANK_15",DRUID,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95852,95854,95850,95851,95853)
				AddVariant(50400,nil,RAID,set,"NORMAL",95252,95254,95250,95251,95253)
				AddVariant(50400,nil,RAID,set,"HEROIC",96596,96598,96594,96595,96597)

	set = AddSet(50400,nil,RAID,15,"DR_TR_HEALER_15",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95841,95844,95843,95840,95842)
				AddVariant(50400,nil,RAID,set,"NORMAL",95241,95244,95243,95240,95242)
				AddVariant(50400,nil,RAID,set,"HEROIC",96585,96588,96587,96584,96586)

	set = AddSet(50400,nil,RAID,14,"DR_TR_CASTER_14",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86647,86644,86645,86648,86696)
				AddVariant(50400,nil,RAID,set,"NORMAL",85307,85304,85305,85308,85356)
				AddVariant(50400,nil,RAID,set,"HEROIC",86934,86937,86936,86933,86930)
	
	set = AddSet(50400,nil,RAID,14,"DR_TR_MELEE_14",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86651,86649,86653,86652,86650)
				AddVariant(50400,nil,RAID,set,"NORMAL",85311,85309,85313,85312,85310)
				AddVariant(50400,nil,RAID,set,"HEROIC",86925,86927,86923,86924,86926)
	
	set = AddSet(50400,nil,RAID,14,"DR_TR_TANK_14",DRUID,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86721,86723,86719,86720,86722)
				AddVariant(50400,nil,RAID,set,"NORMAL",85381,85383,85379,85380,85382)
				AddVariant(50400,nil,RAID,set,"HEROIC",86940,86942,86938,86939,86941)
	
	set = AddSet(50400,nil,RAID,14,"DR_TR_HEALER_14",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86697,86694,86695,86698,86646)
				AddVariant(50400,nil,RAID,set,"NORMAL",85357,85354,85355,85358,85306)
				AddVariant(50400,nil,RAID,set,"HEROIC",86929,86932,86931,86928,86935)
	
	set = AddSet(50400,nil,RAID,13,"DR_TR_CASTER_13",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78791,78839,78757,78771,78809)
				AddVariant(50400,nil,RAID,set,"NORMAL",77019,77022,77021,77018,77020)
				AddVariant(50400,nil,RAID,set,"HEROIC",78696,78744,78662,78676,78714)

	set = AddSet(50400,nil,RAID,13,"DR_TR_MELEE_13",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78789,78838,78760,78779,78808)
				AddVariant(50400,nil,RAID,set,"NORMAL",77015,77017,77013,77014,77016)
				AddVariant(50400,nil,RAID,set,"HEROIC",78694,78743,78665,78684,78713)

	set = AddSet(50400,nil,RAID,13,"DR_TR_HEALER_13",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78785,78835,78755,78775,78805)
				AddVariant(50400,nil,RAID,set,"NORMAL",76750,76753,76752,76749,76751)
				AddVariant(50400,nil,RAID,set,"HEROIC",78690,78740,78660,78680,78710)
	
	set = AddSet(50400,nil,RAID,12,"DR_TR_CASTER_12",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71108,71111,71110,71107,71109)
				AddVariant(50400,nil,RAID,set,"HEROIC",71497,71500,71499,71496,71498)

	set = AddSet(50400,nil,RAID,12,"DR_TR_MELEE_12",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71098,71101,71100,71097,71099)
				AddVariant(50400,nil,RAID,set,"HEROIC",71488,71490,71486,71487,71489)

	set = AddSet(50400,nil,RAID,12,"DR_TR_HEALER_12",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71103,71106,71105,71102,71104)
				AddVariant(50400,nil,RAID,set,"HEROIC",71492,71495,71494,71491,71493)
	
	set = AddSet(50400,nil,RAID,11,"DR_TR_CASTER_11",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60282,60284,60281,60285,60283)
				AddVariant(50400,nil,RAID,set,"HEROIC",65200,65203,65202,65199,65201)

	set = AddSet(50400,nil,RAID,11,"DR_TR_MELEE_11",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60286,60289,60287,60290,60288)
				AddVariant(50400,nil,RAID,set,"HEROIC",65190,65193,65192,65189,65191)

	set = AddSet(50400,nil,RAID,11,"DR_TR_HEALER_11",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60277,60279,60276,60280,60278)
				AddVariant(50400,nil,RAID,set,"HEROIC",65195,65198,65197,65194,65196)

	set = AddSet(50400,nil,RAID,10,"DR_TR_CASTER_10",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50821,50819,50823,50822,50820)
				AddVariant(50400,nil,RAID,set,"NORMAL",51149,51147,51145,51148,51146)
				AddVariant(50400,nil,RAID,set,"HEROIC",51290,51292,51294,51291,51293)

	set = AddSet(50400,nil,RAID,10,"DR_TR_MELEE_10",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50826,50824,50828,50827,50825)
				AddVariant(50400,nil,RAID,set,"NORMAL",51143,51140,51141,51144,51142)
				AddVariant(50400,nil,RAID,set,"HEROIC",51296,51299,51298,51295,51297)

	set = AddSet(50400,nil,RAID,10,"DR_TR_HEALER_10",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50108,50113,50106,50107,50109)
				AddVariant(50400,nil,RAID,set,"NORMAL",51137,51135,51139,51138,51136)
				AddVariant(50400,nil,RAID,set,"HEROIC",51302,51304,51300,51301,51303)
	
	set = AddSet(50400,nil,RAID,9,"DR_TR_CASTER_A_09",DRUID,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48158,48161,48159,48162,48160)
				AddVariant(50400,nil,RAID,set,"NORMAL",48164,48167,48166,48163,48165)
				AddVariant(50400,nil,RAID,set,"HEROIC",48171,48168,48169,48172,48170)

	set = AddSet(50400,nil,RAID,9,"DR_TR_MELEE_A_09",DRUID,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48214,48217,48216,48213,48215)
				AddVariant(50400,nil,RAID,set,"NORMAL",48211,48208,48209,48212,48210)
				AddVariant(50400,nil,RAID,set,"HEROIC",48204,48207,48206,48203,48205)

	set = AddSet(50400,nil,RAID,9,"DR_TR_HEALER_A_09",DRUID,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48102,48131,48129,48132,48130)
				AddVariant(50400,nil,RAID,set,"NORMAL",48134,48137,48136,48133,48135)
				AddVariant(50400,nil,RAID,set,"HEROIC",48141,48138,48139,48142,48140)
	
	set = AddSet(50400,nil,RAID,9,"DR_TR_CASTER_H_09",DRUID,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48174,48177,48176,48173,48175)
				AddVariant(50400,nil,RAID,set,"NORMAL",48181,48178,48179,48182,48180)
				AddVariant(50400,nil,RAID,set,"HEROIC",48184,48187,48186,48183,48185)

	set = AddSet(50400,nil,RAID,9,"DR_TR_MELEE_H_09",DRUID,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48188,48191,48189,48192,48190)
				AddVariant(50400,nil,RAID,set,"NORMAL",48194,48197,48196,48193,48195)
				AddVariant(50400,nil,RAID,set,"HEROIC",48201,48198,48199,48202,48200)

	set = AddSet(50400,nil,RAID,9,"DR_TR_HEALER_H_09",DRUID,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48154,48157,48156,48153,48155)
				AddVariant(50400,nil,RAID,set,"NORMAL",48151,48148,48149,48152,48150)
				AddVariant(50400,nil,RAID,set,"HEROIC",48144,48147,48146,48143,48145)

	set = AddSet(50400,nil,RAID,8,"DR_TR_CASTER_08",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",46313,45352,45354,45351,45353)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46191,46196,46194,46189,46192)
	
	set = AddSet(50400,nil,RAID,8,"DR_TR_MELEE_08",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45356,45359,45358,45355,45357)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46161,46157,46159,46158,46160)

	set = AddSet(50400,nil,RAID,8,"DR_TR_HEALER_08",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45346,45349,45348,45345,45347)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46184,46187,46186,46183,46185)
	
	set = AddSet(50400,nil,RAID,7,"DR_TR_CASTER_07",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39545,39548,39547,39544,39546)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40467,40470,40469,40466,40468)
	
	set = AddSet(50400,nil,RAID,7,"DR_TR_MELEE_07",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39553,39556,39554,39557,39555)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40473,40494,40471,40472,40493)

	set = AddSet(50400,nil,RAID,7,"DR_TR_HEALER_07",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39531,39542,39538,39543,39539)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40461,40465,40463,40460,40462)
	
	set = AddSet(50400,nil,RAID,6,"DR_TR_MELEE_06",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_MELEE_06",31039,31048,31042,34444,31034,34556,31044,34573)
				
	set = AddSet(50400,nil,RAID,6,"DR_TR_HEALER_06",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_HEALER_06",31037,31047,31041,34445,31032,34554,31045,34571)
				
	set = AddSet(50400,nil,RAID,6,"DR_TR_CASTER_06",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_CASTER_06",31040,31049,31043,34446,31035,34555,31046,34572)
	
	set = AddSet(50400,nil,RAID,5,"DR_TR_MELEE_05",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_MELEE_05",30228,30230,30222,30223,30229)
	
	set = AddSet(50400,nil,RAID,5,"DR_TR_HEALER_05",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_HEALER_05",30219,30221,30216,30217,30220)
	
	set = AddSet(50400,nil,RAID,5,"DR_TR_CASTER_05",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_CASTER_05",30233,30235,30231,30232,30234)
	
	set = AddSet(50400,nil,RAID,4,"DR_TR_MELEE_04",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_MELEE_04",29098,29100,29096,29097,29099)
	
	set = AddSet(50400,nil,RAID,4,"DR_TR_HEALER_04",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_HEALER_04",29086,29089,29087,29090,29088)
	
	set = AddSet(50400,nil,RAID,4,"DR_TR_CASTER_04",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_CASTER_04",29093,29095,29091,29092,29094)
	
	set = AddSet(50400,nil,RAID,3,"DR_TR_03",DRUID,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_03",22490,22491,22488,22495,22493,22494,22489,22492,23064)
	
	set = AddSet(50400,nil,RAID,2,"DR_TR_02",DRUID,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_02",16900,16902,16897,16904,16899,16903,16901,16898)
	
	set = AddSet(50400,nil,RAID,1,"DR_TR_01",DRUID,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_01",16834,16836,16833,16830,16831,16828,16835,16829)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"DR_CD_90",DRUID,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"DR_CD_90",90062,90065,90064,90066,90061,90059,90063,90060)

	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"DR_DG_03",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_03",28348,27737,28202,27468,27873)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_LEATHER_03",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_LEATHER_03",28224,27797,28264,27531,27837)
				
	set = AddSet(50400,nil,DUNGEON,22,"DR_DG_AQ_2",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_AQ_2",21353,21354,21357,21356,21355)
				
	set = AddSet(50400,nil,DUNGEON,21,"DR_DG_AQ_1",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_AQ_1",21407,21409,21408)
				
	set = AddSet(50400,nil,DUNGEON,20,"DR_DG_02",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_02",22109,22112,22113,22108,22110,22106,22111,22107)
				
	set = AddSet(50400,nil,DUNGEON,10,"DR_DG_01",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_01",16720,16718,16706,16714,16717,16716,16719,16715)

	-- PvP
	set = AddSet(50400,nil,PVP,160,"DR_PVP_16",DRUID,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",115203,115206,115205,115202,115204)
				AddVariant(50400,nil,PVP,set,"COMBATANT",115055,115058,115057,115054,115056)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",115635,115638,115637,115634,115636)
				
	set = AddSet(50400,nil,PVP,160,"DR_PVP_16",DRUID,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",119980,119983,119982,119979,119981)
				AddVariant(50400,nil,PVP,set,"COMBATANT",119845,119848,119847,119844,119846)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",111108,111111,111110,111107,111109)
				
	set = AddSet(50400,nil,PVP,150,"DR_PVP_MELEE_15",DRUID,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102653,102741,102740,102739,102645)
				AddVariant(50400,nil,PVP,set,"ELITE",103010,103013,103012,103009,103138,103011,103137)
				
	set = AddSet(50400,nil,PVP,150,"DR_PVP_HEALER_15",DRUID,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102776,102658,102721,102657,102761)
				AddVariant(50400,nil,PVP,set,"ELITE",103017,103020,103019,103016,103014,103018,103015)
				
	set = AddSet(50400,nil,PVP,150,"DR_PVP_CASTER_15",DRUID,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102634,102700,102614,102696,102767)
				AddVariant(50400,nil,PVP,set,"ELITE",103025,103028,103027,103024,103022,103026,103023)
				
	set = AddSet(50400,nil,PVP,150,"DR_PVP_MELEE_15",DRUID,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103381,103382,103383,103384,103385)
				AddVariant(50400,nil,PVP,set,"ELITE",103012,103009,103010,103011,103013,103137,103138)
				
	set = AddSet(50400,nil,PVP,150,"DR_PVP_HEALER_15",DRUID,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103389,103390,103391,103392,103393)
				AddVariant(50400,nil,PVP,set,"ELITE",103017,103014,103015,103016,103018,103019,103020)
				
	set = AddSet(50400,nil,PVP,150,"DR_PVP_CASTER_15",DRUID,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103398,103399,103400,103401,103402)
				AddVariant(50400,nil,PVP,set,"ELITE",103025,102022,103023,103024,103026,103027,103028)
				
	set = AddSet(50400,nil,PVP,140,"DR_PVP_MELEE_14",DRUID,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100255,100261,100259,100253,100257)
				AddVariant(50400,nil,PVP,set,"ELITE",100256,100262,100260,100254,100258)
				
	set = AddSet(50400,nil,PVP,140,"DR_PVP_HEALER_14",DRUID,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100270,100276,100274,100268,100272)
				AddVariant(50400,nil,PVP,set,"ELITE",100271,100277,100275,100269,100273)
				
	set = AddSet(50400,nil,PVP,140,"DR_PVP_CASTER_14",DRUID,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100287,100293,100291,100285,100289)
				AddVariant(50400,nil,PVP,set,"ELITE",100288,100294,100292,100286,100290)
				
	set = AddSet(50400,nil,PVP,140,"DR_PVP_MELEE_14",DRUID,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100597,100687,100686,100685,100598)
				AddVariant(50400,nil,PVP,set,"ELITE",100256,100262,100260,100254,100258)
				
	set = AddSet(50400,nil,PVP,140,"DR_PVP_HEALER_14",DRUID,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100722,100602,100667,100601,100707)
				AddVariant(50400,nil,PVP,set,"ELITE",100271,100277,100275,100269,100273)
				
	set = AddSet(50400,nil,PVP,140,"DR_PVP_CASTER_14",DRUID,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100577,100646,100557,100642,100713)
				AddVariant(50400,nil,PVP,set,"ELITE",100288,100294,100292,100286,100290)
				
end



local function AddHunterSets()
	local set = ""
	
	-- Legendary
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",102248)
				
	set = AddSet(50400,nil,LEGENDARY,70,"LG_RANGED_70",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_RANGED_70",34334)

	-- Raid
	set = AddSet(60000,nil,RAID,17,"HU_TR_17",HUNTER,RANGED,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115545,115547,115548,115549,115546)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115545,566),T17(115547,566),T17(115548,566),T17(115549,566),T17(115546,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115545,567),T17(115547,567),T17(115548,567),T17(115549,567),T17(115546,567))
				
	set = AddSet(50400,nil,RAID,16,"HU_TR_RANGED_16",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99080,99082,99085,99086,99081)
				AddVariant(60000,nil,RAID,set,"NORMAL",99660,99574,99577,99578,99573)
				AddVariant(60000,nil,RAID,set,"HEROIC",99157,99159,99167,99168,99158)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99402,99404,99405,99406,99403)

	set = AddSet(50400,nil,RAID,15,"HU_TR_RANGED_15",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95884,95886,95882,95883,95885)
				AddVariant(50400,nil,RAID,set,"NORMAL",95257,95259,95255,95256,95258)
				AddVariant(50400,nil,RAID,set,"HEROIC",96628,96630,96626,96627,96629)

	set = AddSet(50400,nil,RAID,14,"HU_TR_RANGED_14",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86636,86634,86638,86637,86635)
				AddVariant(50400,nil,RAID,set,"NORMAL",85296,85294,85298,85297,85295)
				AddVariant(50400,nil,RAID,set,"HEROIC",87004,87006,87002,87003,87005)

	set = AddSet(50400,nil,RAID,13,"HU_TR_RANGED_13",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78793,78832,78756,78769,78804)
				AddVariant(50400,nil,RAID,set,"NORMAL",77030,77032,77028,77029,77031)
				AddVariant(50400,nil,RAID,set,"HEROIC",78698,78737,78661,78674,78709)

	set = AddSet(50400,nil,RAID,12,"HU_TR_RANGED_12",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71051,71053,71054,71050,71052)
				AddVariant(50400,nil,RAID,set,"HEROIC",71503,71505,71501,71502,71504)

	set = AddSet(50400,nil,RAID,11,"HU_TR_RANGED_11",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60303,60306,60304,60307,60305)
				AddVariant(50400,nil,RAID,set,"HEROIC",65206,65208,65204,65205,65207)

	set = AddSet(50400,nil,RAID,10,"HU_TR_RANGED_10",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50115,50117,50118,50114,50116)
				AddVariant(50400,nil,RAID,set,"NORMAL",51153,51151,51150,51154,51152)
				AddVariant(50400,nil,RAID,set,"HEROIC",51286,51288,51289,51285,51287)

	set = AddSet(50400,nil,RAID,9,"HU_TR_RANGED_A_09",HUNTER,RANGED,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48250,48253,48251,48254,48252)
				AddVariant(50400,nil,RAID,set,"NORMAL",48257,48259,48255,48256,48258)
				AddVariant(50400,nil,RAID,set,"HEROIC",48262,48260,48264,48263,48261)
				
	set = AddSet(50400,nil,RAID,9,"HU_TR_RANGED_H_09",HUNTER,RANGED,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48277,48279,48275,48276,48278)
				AddVariant(50400,nil,RAID,set,"NORMAL",48272,48270,48274,48273,48271)
				AddVariant(50400,nil,RAID,set,"HEROIC",48267,48269,48265,48266,48268)

	set = AddSet(50400,nil,RAID,8,"HU_TR_RANGED_08",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45361,45363,45364,45360,45362)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46143,46145,46141,46142,46144)

	set = AddSet(50400,nil,RAID,7,"HU_TR_RANGED_07",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39578,39581,39579,39582,39580)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40505,40507,40503,40504,40506)

	set = AddSet(50400,nil,RAID,6,"HU_TR_RANGED_06",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_RANGED_06",31003,31006,31004,34443,31001,34549,31005,34570)

	set = AddSet(50400,nil,RAID,5,"HU_TR_RANGED_05",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_RANGED_05",30141,30143,30139,30140,30142)

	set = AddSet(50400,nil,RAID,4,"HU_TR_RANGED_04",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_RANGED_04",29081,29084,29082,29085,29083)

	set = AddSet(50400,nil,RAID,3,"HU_TR_03",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_03",22438,22439,22436,22443,22441,22442,22437,22440,23067)

	set = AddSet(50400,nil,RAID,2,"HU_TR_02",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_02",16939,16937,16942,16935,16940,16936,16938,16941)

	set = AddSet(50400,nil,RAID,1,"HU_TR_01",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_01",16846,16848,16845,16850,16852,16851,16847,16849)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"HU_CD_90",HUNTER,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"HU_CD_90",90072,90074,90070,90075,90071,90068,90073,90069)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"HU_DG_03",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_03",28275,27801,28228,27474,27874)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_MAIL_03",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_MAIL_03",28192,27713,28401,27528,27936)
				
	set = AddSet(50400,nil,DUNGEON,22,"HU_DG_AQ_2",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_AQ_2",21366,21367,21370,21368,21365)
				
	set = AddSet(50400,nil,DUNGEON,21,"HU_DG_AQ_1",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_AQ_1",21401,21403,21402)
				
	set = AddSet(50400,nil,DUNGEON,20,"HU_DG_02",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_02",22013,22016,22060,22011,22015,22010,22017,22061)
				
	set = AddSet(50400,nil,DUNGEON,10,"HU_DG_01",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_01",16677,16679,16674,16681,16676,16680,16678,16675)
				
	-- PvP
	set = AddSet(50400,nil,PVP,160,"HU_PVP_16",HUNTER,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",115209,115211,115207,115208,115210)
				AddVariant(50400,nil,PVP,set,"COMBATANT",115061,115063,115059,115060,115062)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",115641,115643,115639,115640,115642)
				
	set = AddSet(50400,nil,PVP,160,"HU_PVP_16",HUNTER,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",119986,119988,119984,119985,119987)
				AddVariant(50400,nil,PVP,set,"COMBATANT",119851,119853,119849,119850,119852)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",111114,111116,111112,111113,111115)
				
	set = AddSet(50400,nil,PVP,150,"HU_PVP_RANGED_15",HUNTER,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102670,102690,102734,102737,102689)
				AddVariant(50400,nil,PVP,set,"ELITE",103038,103033,103035,103037,103039,103040,103041)
				
	set = AddSet(50400,nil,PVP,150,"HU_PVP_RANGED_15",HUNTER,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103416,103417,103418,103419,103420)
				AddVariant(50400,nil,PVP,set,"ELITE",103038,103033,103035,103037,103039,103040,103041)
				
	set = AddSet(50400,nil,PVP,140,"HU_PVP_RANGED_14",HUNTER,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100322,100326,100318,100320,100324)
				AddVariant(50400,nil,PVP,set,"ELITE",100323,100327,100319,100321,100325)
				
	set = AddSet(50400,nil,PVP,140,"HU_PVP_RANGED_14",HUNTER,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100636,100680,100635,100683,100614)
				AddVariant(50400,nil,PVP,set,"ELITE",100323,100327,100319,100321,100325)
	
end

local function AddMageSets()
	local set = ""
	
  -- Legendaries
	set = AddSet(50400,nil,LEGENDARY,1,"LG_CASTER_INT_90",MAGE,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",102246)
				
	set = AddSet(50400,nil,LEGENDARY,1,"LG_85",MAGE,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",71086)
	
	-- Raid
	set = AddSet(60000,nil,RAID,17,"MA_TR_17",MAGE,CASTER,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115553,115551,115550,115552,115554)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115553,566),T17(115551,566),T17(115550,566),T17(115552,566),T17(115554,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115553,567),T17(115551,567),T17(115550,567),T17(115552,567),T17(115554,567))
				
	set = AddSet(50400,nil,RAID,16,"MA_TR_CASTER_16",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99084,99079,99078,99083,99077)
				AddVariant(60000,nil,RAID,set,"NORMAL",99576,99659,99658,99575,99657)
				AddVariant(60000,nil,RAID,set,"HEROIC",99161,99153,99152,99160,99162)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99398,99401,99400,99397,99399)

	set = AddSet(50400,nil,RAID,15,"MA_TR_CASTER_15",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95891,95894,95893,95890,95892)
				AddVariant(50400,nil,RAID,set,"NORMAL",95261,95264,95263,95260,95262)
				AddVariant(50400,nil,RAID,set,"HEROIC",96635,96638,96637,96634,96636)

	set = AddSet(50400,nil,RAID,14,"MA_TR_CASTER_14",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86717,86714,86715,86718,86716)
				AddVariant(50400,nil,RAID,set,"NORMAL",85377,85374,85375,85378,85376)
				AddVariant(50400,nil,RAID,set,"HEROIC",87008,87011,87010,87007,87009)

	set = AddSet(50400,nil,RAID,13,"MA_TR_CASTER_13",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78796,78843,78824,78766,78815)
				AddVariant(50400,nil,RAID,set,"NORMAL",76213,76216,76215,76212,76214)
				AddVariant(50400,nil,RAID,set,"HEROIC",78701,78748,78729,78671,78720)

	set = AddSet(50400,nil,RAID,12,"MA_TR_CASTER_12",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71287,71290,71289,71286,71288)
				AddVariant(50400,nil,RAID,set,"HEROIC",71508,71511,71510,71507,71509)

	set = AddSet(50400,nil,RAID,11,"MA_TR_CASTER_11",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60243,60246,60244,60247,60245)
				AddVariant(50400,nil,RAID,set,"HEROIC",65210,65213,65212,65209,65211)

	set = AddSet(50400,nil,RAID,10,"MA_TR_CASTER_10",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50276,50279,50278,50275,50277)
				AddVariant(50400,nil,RAID,set,"NORMAL",51158,51155,51156,51159,51157)
				AddVariant(50400,nil,RAID,set,"HEROIC",51281,51284,51283,51280,51282)

	set = AddSet(50400,nil,RAID,9,"DR_TR_CASTER_A_09",MAGE,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",47748,47751,47749,47752,47750)
				AddVariant(50400,nil,RAID,set,"NORMAL",47754,47757,47756,47753,47755)
				AddVariant(50400,nil,RAID,set,"HEROIC",47761,47758,47759,47762,47760)
				
	set = AddSet(50400,nil,RAID,9,"MA_TR_CASTER_H_09",MAGE,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",47774,47777,47776,47773,47775)
				AddVariant(50400,nil,RAID,set,"NORMAL",47771,47768,47769,47772,47770)
				AddVariant(50400,nil,RAID,set,"HEROIC",47764,47767,47766,47763,47765)

	set = AddSet(50400,nil,RAID,8,"MA_TR_CASTER_08",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45365,45369,45368,46131,45367)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46129,46134,46130,46132,46133)

	set = AddSet(50400,nil,RAID,7,"MA_TR_CASTER_07",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39491,39494,39492,39495,39493)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40416,40419,40418,40415,40417)

	set = AddSet(50400,nil,RAID,6,"MA_TR_CASTER_06",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_CASTER_06",31056,31059,31057,34447,31055,34557,31058,34574)

	set = AddSet(50400,nil,RAID,5,"MA_TR_CASTER_05",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_CASTER_05",30206,30210,30196,30205,30207)

	set = AddSet(50400,nil,RAID,4,"MA_TR_CASTER_04",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_CASTER_04",29076,29079,29077,29080,29078)

	set = AddSet(50400,nil,RAID,3,"MA_TR_03",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_03",22498,22499,22496,22503,22501,22502,22497,22500,23062)

	set = AddSet(50400,nil,RAID,2,"MA_TR_02",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_02",16914,16917,16916,16918,16913,16818,16915,16912)

	set = AddSet(50400,nil,RAID,1,"MA_TR_01",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_01",16795,16797,16798,16799,16801,16802,16796,16800)

	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"MA_CD_90",MAGE,CASTER,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"MA_CD_90",90082,90085,90084,90086,90081,90079,90083,90080)

	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"MA_DG_03",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_03",28278,27738,28229,27508,27838)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_CLOTH_03",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_CLOTH_03",28193,27796,28191,27465,27907)
				
	set = AddSet(50400,nil,DUNGEON,22,"MA_DG_AQ_2",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_AQ_2",21347,21345,21343,21346,21344)
				
	set = AddSet(50400,nil,DUNGEON,21,"MA_DG_AQ_1",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_AQ_1",21413,21415,21414)
				
	set = AddSet(50400,nil,DUNGEON,20,"MA_DG_02",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_02",22065,22068,22069,22063,22066,22062,22067,22064)
				
	set = AddSet(50400,nil,DUNGEON,10,"MA_DG_01",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_01",16686,16689,16688,16683,16684,16685,16687,16682)
					
	-- PvP
	set = AddSet(50400,nil,PVP,160,"MA_PVP_16",MAGE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",115221,115224,115223,115220,115222)
				AddVariant(50400,nil,PVP,set,"COMBATANT",115091,115094,115093,115090,115092)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",115678,115681,115680,115677,115679)
				
	set = AddSet(50400,nil,PVP,160,"MA_PVP_16",MAGE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",119998,120001,120000,119997,119999)
				AddVariant(50400,nil,PVP,set,"COMBATANT",119874,119877,119876,119873,119875)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",111151,111154,111153,111150,111152)
				
	set = AddSet(50400,nil,PVP,150,"MA_PVP_CASTER_15",MAGE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102648,102673,102715,102735,102667)
				AddVariant(50400,nil,PVP,set,"ELITE",103043,102991,102994,103042,103044,103045,103046)
				
	set = AddSet(50400,nil,PVP,150,"MA_PVP_CASTER_15",MAGE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103421,103422,103423,103424,103425)
				AddVariant(50400,nil,PVP,set,"ELITE",103043,102991,102994,103042,103044,103045,103046)
				
	set = AddSet(50400,nil,PVP,140,"MA_PVP_CASTER_14",MAGE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100330,100336,100334,100328,100332)
				AddVariant(50400,nil,PVP,set,"ELITE",100331,100337,100335,100329,100333)
				
	set = AddSet(50400,nil,PVP,140,"MA_PVP_CASTER_14",MAGE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100611,100619,100661,100681,100592)
				AddVariant(50400,nil,PVP,set,"ELITE",100331,100337,100335,100329,100333)
				
end


local function AddMonkSets()
	local set = ""
	
	-- Legendary
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_AGI_90",MONK,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_AGI_90",102245)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",MONK,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",102248)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",MONK,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",102247)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",MONK,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",46017)
				
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",MONK,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",32837,32838)

	-- Raid
	set = AddSet(60000,nil,RAID,17,"MO_TR_17",MONK,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115556,115559,115558,115555,115557)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115556,566),T17(115559,566),T17(115558,566),T17(115555,566),T17(115557,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115556,567),T17(115559,567),T17(115558,567),T17(115555,567),T17(115557,567))

	set = AddSet(50400,nil,RAID,16,"MO_TR_TANK_16",MONK,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99065,99051,99063,99064,99050)
				AddVariant(60000,nil,RAID,set,"NORMAL",99607,99565,99643,99644,99606)
				AddVariant(60000,nil,RAID,set,"HEROIC",99142,99144,99140,99141,99143)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99384,99386,99382,99383,99385)

	set = AddSet(50400,nil,RAID,16,"MO_TR_MELEE_16",MONK,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99073,99075,99071,99072,99074)
				AddVariant(60000,nil,RAID,set,"NORMAL",99653,99655,99555,99556,99654)
				AddVariant(60000,nil,RAID,set,"HEROIC",99156,99146,99154,99155,99145)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99393,99395,99396,99392,99394)

	set = AddSet(50400,nil,RAID,16,"MO_TR_HEALER_16",MONK,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99069,99062,99061,99068,99070)
				AddVariant(60000,nil,RAID,set,"NORMAL",99553,99642,99641,99552,99554)
				AddVariant(60000,nil,RAID,set,"HEROIC",99148,99151,99150,99147,99149)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99389,99381,99391,99388,99390)

	set = AddSet(50400,nil,RAID,15,"MO_TR_TANK_15",MONK,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95907,95909,95905,95906,95908)
				AddVariant(50400,nil,RAID,set,"NORMAL",95277,95279,95275,95276,95278)
				AddVariant(50400,nil,RAID,set,"HEROIC",96651,96653,96649,96650,96652)

	set = AddSet(50400,nil,RAID,15,"MO_TR_MELEE_15",MONK,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95897,95899,95895,95896,95898)
				AddVariant(50400,nil,RAID,set,"NORMAL",95267,95269,95265,95266,95268)
				AddVariant(50400,nil,RAID,set,"HEROIC",96641,96643,96639,96640,96642)

	set = AddSet(50400,nil,RAID,15,"MO_TR_HEALER_15",MONK,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95901,95904,95903,95900,95902)
				AddVariant(50400,nil,RAID,set,"NORMAL",95271,95274,95273,95270,95272)
				AddVariant(50400,nil,RAID,set,"HEROIC",96645,96648,96647,96644,96646)
	
	set = AddSet(50400,nil,RAID,14,"MO_TR_TANK_14",MONK,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86726,86724,86728,86727,86725)
				AddVariant(50400,nil,RAID,set,"NORMAL",85386,85384,85388,85387,85385)
				AddVariant(50400,nil,RAID,set,"HEROIC",87096,87098,87094,87095,87097)

	set = AddSet(50400,nil,RAID,14,"MO_TR_MELEE_14",MONK,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86730,86733,86732,86729,86731)
				AddVariant(50400,nil,RAID,set,"NORMAL",85390,85393,85392,85389,85391)
				AddVariant(50400,nil,RAID,set,"HEROIC",87090,87093,87092,87089,87091)

	set = AddSet(50400,nil,RAID,14,"MO_TR_HEALER_14",MONK,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86736,86738,86734,86735,86737)
				AddVariant(50400,nil,RAID,set,"NORMAL",85396,85398,85394,85395,85397)
				AddVariant(50400,nil,RAID,set,"HEROIC",87086,87088,87084,87085,87087)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"CHALLENGE",MONK,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"MO_CD_90",90092,90094,90090,90095,90091,90088,90093,90089)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,1,"DG_LEATHER_03",MONK,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_LEATHER_03",28224,27797,28264,27531,27837)

	-- PvP
	set = AddSet(50400,nil,PVP,160,"MO_PVP_16",MONK,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",115229,115231,115232,115228,115230)
				AddVariant(50400,nil,PVP,set,"COMBATANT",115102,115104,115105,115101,115103)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",115692,115694,115695,115691,115693)
				
	set = AddSet(50400,nil,PVP,160,"MO_PVP_16",MONK,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",120006,120008,120009,120005,120007)
				AddVariant(50400,nil,PVP,set,"COMBATANT",119885,119887,119888,119884,119886)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",111165,111167,111168,111164,111166)
				
	set = AddSet(50400,nil,PVP,150,"MO_PVP_HEALER_15",MONK,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102628,102777,102763,102627,102762)
				AddVariant(50400,nil,PVP,set,"ELITE",103055,103057,103058,103054,103134,103056,103133)
				
	set = AddSet(50400,nil,PVP,150,"MO_PVP_MELEE_15",MONK,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102712,102626,102720,102675,102656)
				AddVariant(50400,nil,PVP,set,"ELITE",103050,103052,103053,103049,103047,103051,103048)
				
	set = AddSet(50400,nil,PVP,150,"MO_PVP_HEALER_15",MONK,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103435,103437,103438,103434,103436)
				AddVariant(50400,nil,PVP,set,"ELITE",103055,103057,103058,103054,103134,103056,103133)
				
	set = AddSet(50400,nil,PVP,150,"MO_PVP_MELEE_15",MONK,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103430,103432,103433,103429,103431)
				AddVariant(50400,nil,PVP,set,"ELITE",103050,103052,103053,103049,103047,103051,103048)
				
	set = AddSet(50400,nil,PVP,140,"MO_PVP_HEALER_14",MONK,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100355,100359,100361,100353,100357)
				AddVariant(50400,nil,PVP,set,"ELITE",100356,100360,100362,100354,100358)
				
	set = AddSet(50400,nil,PVP,140,"MO_PVP_MELEE_14",MONK,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",100345,100349,100351,100343,100347)
				AddVariant(50400,nil,PVP,set,"ELITE",100346,100350,100352,100344,100348)
				
	set = AddSet(50400,nil,PVP,140,"MO_PVP_HEALER_14",MONK,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100571,1007223,100709,100570,100708)
				AddVariant(50400,nil,PVP,set,"ELITE",100356,100360,100362,100354,100358)
				
	set = AddSet(50400,nil,PVP,140,"MO_PVP_MELEE_14",MONK,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",100658,100569,100666,1006221,100600)
				AddVariant(50400,nil,PVP,set,"ELITE",100346,100350,100352,100344,100348)
				
end

local function AddPaladinSets()
	local set = ""
	
	-- Legendary
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_STR_90",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_STR_90",102249)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_STR_90",PALADIN,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_STR_90",102250)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",102247)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",49623)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",PALADIN,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",49623)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",46017)
	
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",17182)
	
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",PALADIN,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",17182)

	-- Raid
	set = AddSet(60000,nil,RAID,17,"PA_TR_17",PALADIN,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115565,115566,115567,115568,115569)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115565,566),T17(115566,566),T17(115567,566),T17(115568,566),T17(115569,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115565,567),T17(115566,567),T17(115567,567),T17(115568,567),T17(115569,567))

	set = AddSet(50400,nil,RAID,16,"PA_TR_HEALER_16",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",98979,99076,99003,98980,98982)
				AddVariant(60000,nil,RAID,set,"NORMAL",99665,99656,99626,99666,99648)
				AddVariant(60000,nil,RAID,set,"HEROIC",99135,99125,99133,99124,99134)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99376,99378,99374,99377,99375)
	
	set = AddSet(50400,nil,RAID,16,"PA_TR_TANK_16",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99029,99027,99031,99026,99028)
				AddVariant(60000,nil,RAID,set,"NORMAL",99596,99594,99598,99593,99595)
				AddVariant(60000,nil,RAID,set,"HEROIC",99128,99130,99126,99129,99127)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99370,99364,99368,99371,99369)

	set = AddSet(50400,nil,RAID,16,"PA_TR_MELEE_16",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",98985,98987,99052,98986,99002)
				AddVariant(60000,nil,RAID,set,"NORMAL",99651,99662,99566,99661,99625)
				AddVariant(60000,nil,RAID,set,"HEROIC",99138,99132,99136,99139,99137)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99379,99373,99387,99372,99380)

	set = AddSet(50400,nil,RAID,15,"PA_TR_HEALER_15",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95915,95916,95918,95917,95919)
				AddVariant(50400,nil,RAID,set,"NORMAL",95285,95286,95288,95287,95289)
				AddVariant(50400,nil,RAID,set,"HEROIC",96659,96660,96662,96661,96663)
	
	set = AddSet(50400,nil,RAID,15,"PA_TR_TANK_15",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95920,95922,95921,95923,95924)
				AddVariant(50400,nil,RAID,set,"NORMAL",95290,95292,95291,95293,95294)
				AddVariant(50400,nil,RAID,set,"HEROIC",96664,96666,96665,96667,96668)

	set = AddSet(50400,nil,RAID,15,"PA_TR_MELEE_15",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95910,95911,95912,95913,95914)
				AddVariant(50400,nil,RAID,set,"NORMAL",95280,95281,95282,95283,95284)
				AddVariant(50400,nil,RAID,set,"HEROIC",96654,96655,96656,96657,96658)
	
	set = AddSet(50400,nil,RAID,14,"PA_TR_HEALER_14",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86686,86684,86688,86687,86685)
				AddVariant(50400,nil,RAID,set,"NORMAL",85346,85344,85348,85347,85345)
				AddVariant(50400,nil,RAID,set,"HEROIC",87106,87108,87104,87105,87107)

	set = AddSet(50400,nil,RAID,14,"PA_TR_TANK_14",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86661,86659,86663,86660,86662)
				AddVariant(50400,nil,RAID,set,"NORMAL",85321,85319,85323,85320,85322)
				AddVariant(50400,nil,RAID,set,"HEROIC",87111,87113,87109,87112,87110)

	set = AddSet(50400,nil,RAID,14,"PA_TR_MELEE_14",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86681,86679,86683,86680,86682)
				AddVariant(50400,nil,RAID,set,"NORMAL",85341,85339,85343,85340,85342)
				AddVariant(50400,nil,RAID,set,"HEROIC",87101,87103,87099,87102,87100)	
	
	set = AddSet(50400,nil,RAID,13,"PA_TR_HEALER_13",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78787,78841,78821,78768,78812)
				AddVariant(50400,nil,RAID,set,"NORMAL",76767,76769,76765,76766,76768)
				AddVariant(50400,nil,RAID,set,"HEROIC",78692,78746,78726,78673,78717)

	set = AddSet(50400,nil,RAID,13,"PA_TR_TANK_13",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78790,78840,78827,78772,78810)
				AddVariant(50400,nil,RAID,set,"NORMAL",77005,77007,77003,77004,77006)
				AddVariant(50400,nil,RAID,set,"HEROIC",78695,78745,78732,78677,78715)

	set = AddSet(50400,nil,RAID,13,"PA_TR_MELEE_13",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78788,78837,78822,78770,78807)
				AddVariant(50400,nil,RAID,set,"NORMAL",76876,76878,76874,76875,76877)
				AddVariant(50400,nil,RAID,set,"HEROIC",78693,78742,78727,78675,78712)
	
	set = AddSet(50400,nil,RAID,12,"PA_TR_HEALER_12",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71093,71095,71091,71092,71094)
				AddVariant(50400,nil,RAID,set,"HEROIC",71519,71521,71517,71518,71520)

	set = AddSet(50400,nil,RAID,12,"PA_TR_TANK_12",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",70948,70946,70950,70949,70947)
				AddVariant(50400,nil,RAID,set,"HEROIC",71524,71526,71522,71523,71525)

	set = AddSet(50400,nil,RAID,12,"PA_TR_MELEE_12",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"HEROIC",71514,71516,71512,71513,71515)
				AddVariant(50400,nil,RAID,set,"NORMAL",71065,71067,71063,71064,71066)
	
	set = AddSet(50400,nil,RAID,11,"PA_TR_HEALER_11",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60359,60360,60361,60362,60363)
				AddVariant(50400,nil,RAID,set,"HEROIC",65219,65220,65221,65222,65223)

	set = AddSet(50400,nil,RAID,11,"PA_TR_TANK_11",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"HEROIC",65224,65225,65226,65227,65228)
				AddVariant(50400,nil,RAID,set,"NORMAL",60354,60355,60356,60357,60358)

	set = AddSet(50400,nil,RAID,11,"PA_TR_MELEE_11",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60344,60345,60346,60347,60348)
				AddVariant(50400,nil,RAID,set,"HEROIC",65214,65215,65216,65217,65218)

	set = AddSet(50400,nil,RAID,10,"PA_TR_HEALER_10",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50867,50865,50869,50868,50866)
				AddVariant(50400,nil,RAID,set,"NORMAL",51167,51166,51165,51169,51168)
				AddVariant(50400,nil,RAID,set,"HEROIC",51272,51273,51274,51270,51271)
	
	set = AddSet(50400,nil,RAID,10,"PA_TR_TANK_10",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50862,50860,50864,50863,50861)
				AddVariant(50400,nil,RAID,set,"NORMAL",51173,51170,51174,51172,51171)
				AddVariant(50400,nil,RAID,set,"HEROIC",51266,51269,51265,51267,51268)

	set = AddSet(50400,nil,RAID,10,"PA_TR_MELEE_10",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50326,50324,50328,50327,50325)
				AddVariant(50400,nil,RAID,set,"NORMAL",51162,51160,51164,51163,51161)
				AddVariant(50400,nil,RAID,set,"HEROIC",51277,51279,51275,51276,51278)
	
	set = AddSet(50400,nil,RAID,9,"PA_TR_HEALER_A_09",PALADIN,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48564,48572,48566,48574,48568)
				AddVariant(50400,nil,RAID,set,"NORMAL",48577,48579,48575,48576,48578)
				AddVariant(50400,nil,RAID,set,"HEROIC",48582,48580,48584,48583,48581)

	set = AddSet(50400,nil,RAID,9,"PA_TR_TANK_A_09",PALADIN,TANK,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48634,48636,48632,48633,48635)
				AddVariant(50400,nil,RAID,set,"NORMAL",48639,48637,48641,48640,48638)
				AddVariant(50400,nil,RAID,set,"HEROIC",48644,48646,48642,48643,48645)

	set = AddSet(50400,nil,RAID,9,"PA_TR_MELEE_A_09",PALADIN,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48604,48606,48602,48603,48605)
				AddVariant(50400,nil,RAID,set,"NORMAL",48609,48611,48607,48608,48610)
				AddVariant(50400,nil,RAID,set,"HEROIC",48614,48612,48616,48615,48613)
	
	set = AddSet(50400,nil,RAID,9,"PA_TR_HEALER_H_09",PALADIN,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48597,48595,48599,48598,48596)
				AddVariant(50400,nil,RAID,set,"NORMAL",48592,48590,48594,48593,48591)
				AddVariant(50400,nil,RAID,set,"HEROIC",48587,48585,48589,48588,48586)

	set = AddSet(50400,nil,RAID,9,"PA_TR_TANK_H_09",PALADIN,TANK,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48654,48656,48652,48653,48655)
				AddVariant(50400,nil,RAID,set,"NORMAL",48659,48661,48657,48658,48660)
				AddVariant(50400,nil,RAID,set,"HEROIC",48649,48647,48651,48650,48648)

	set = AddSet(50400,nil,RAID,9,"PA_TR_MELEE_H_09",PALADIN,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48629,48627,48631,48630,48628)
				AddVariant(50400,nil,RAID,set,"NORMAL",48624,48622,48626,48625,48623)
				AddVariant(50400,nil,RAID,set,"HEROIC",48619,48621,48617,48618,48620)
	
	set = AddSet(50400,nil,RAID,8,"PA_TR_HEALER_08",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45372,45373,45374,45370,45371)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46180,46182,46178,46179,46181)

	set = AddSet(50400,nil,RAID,8,"PA_TR_TANK_08",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45382,45385,45381,45383,45384)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46175,46177,46173,46174,46176)

	set = AddSet(50400,nil,RAID,8,"PA_TR_MELEE_08",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45377,45380,45375,45376,45379)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46156,46152,46154,46155,46153)
	
	set = AddSet(50400,nil,RAID,7,"PA_TR_HEALER_07",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39628,39631,39629,39632,39630)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40571,40573,40569,40570,40572)

	set = AddSet(50400,nil,RAID,7,"PA_TR_TANK_07",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39640,39642,39638,39639,39641)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40581,40584,40579,40580,40583)

	set = AddSet(50400,nil,RAID,7,"PA_TR_MELEE_07",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39635,39637,39633,39634,39636)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40576,40578,40574,40575,40577)

	set = AddSet(50400,nil,RAID,6,"PA_TR_HEALER_06",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_HEALER_06",30988,30996,30992,34432,30983,34487,30994,34559)
	
	set = AddSet(50400,nil,RAID,6,"PA_TR_TANK_06",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_06",30987,30998,30991,34433,30985,34488,30995,34560)
	
	set = AddSet(50400,nil,RAID,6,"PA_TR_MELEE_06",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_06",30989,30997,30990,34431,30982,34485,30993,34561)

	set = AddSet(50400,nil,RAID,5,"PA_TR_HEALER_05",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_HEALER_05",30136,30138,30134,30135,30137)

	set = AddSet(50400,nil,RAID,5,"PA_TR_TANK_05",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_05",30125,30127,30123,30124,30126)

	set = AddSet(50400,nil,RAID,5,"PA_TR_MELEE_05",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_MELEE_05",30131,30133,30129,30130,30132)

	set = AddSet(50400,nil,RAID,4,"PA_TR_HEALER_04",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_HEALER_04",29061,29064,29062,29065,29063)

	set = AddSet(50400,nil,RAID,4,"PA_TR_TANK_04",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_04",29068,29070,29066,29067,29069)

	set = AddSet(50400,nil,RAID,4,"PA_TR_MELEE_04",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_MELEE_04",29073,29075,29071,29072,29074)
	
	set = AddSet(50400,nil,RAID,3,"PA_TR_03",PALADIN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_03",22428,22429,22425,22424,22426,22431,22427,22430,23066)
	
	set = AddSet(50400,nil,RAID,2,"PA_TR_02",PALADIN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_02",16955,16953,16958,16951,16956,16952,16954,16957)
	
	set = AddSet(50400,nil,RAID,1,"PA_TR_01",PALADIN,ANY,ANY,60)
				AddVariant(50400,nil,RAID,set,"PA_TR_01",16854,16856,16853,16857,16860,16858,16855,16859)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,90,"PA_CD_90",PALADIN,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"PA_CD_90",90100,90102,90098,90103,90099,90096,90101,90097)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"PA_DG_03",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_03",28285,27739,28203,27535,27839)
	
	set = AddSet(50400,nil,DUNGEON,31,"DG_PLATE_03",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_PLATE_03",28225,27771,28403,27497,27870)
	
	set = AddSet(50400,nil,DUNGEON,22,"PA_DG_AQ_2",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_AQ_2",21389,21387,21390,21391,21388)
	
	set = AddSet(50400,nil,DUNGEON,21,"PA_DG_AQ_1",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_AQ_1",21395,21397,21396)
	
	set = AddSet(50400,nil,DUNGEON,20,"PA_DG_02",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_02",22091,22093,22089,22088,22090,22086,22092,22087)
	
	set = AddSet(50400,nil,DUNGEON,10,"PA_DG_01",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_01",16727,16729,16726,16722,16724,16723,16728,16725)

	-- PvP
	set = AddSet(50400,nil,PVP,15,"PA_PVP_HEALER_15",PALADIN,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102632,102697,102722,102768,102635)
				AddVariant(50400,nil,PVP,set,"ELITE",103069,103065,103066,103068,103070,103071,103072)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_MELEE_15",PALADIN,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102630,102747,102779,102780,102744)
				AddVariant(50400,nil,PVP,set,"ELITE",103062,103059,103060,103061,103063,103064,103067)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_HEALER_15",PALADIN,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103450,103451,103452,103453,103454)
				AddVariant(50400,nil,PVP,set,"ELITE",103069,103065,103066,103068,103070,103071,103072)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_MELEE_15",PALADIN,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103439,103440,103441,103442,103443)
				AddVariant(50400,nil,PVP,set,"ELITE",103062,103059,103060,103061,103063,103064,103067)
	
end

local function AddPriestSets()
	local set = ""
	
	-- Legendary
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",102247)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",102246)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",PRIEST,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",71086)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",PRIEST,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",46017)

	-- Raid
	set = AddSet(60000,nil,RAID,17,"PR_TR_17",PRIEST,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115560,115561,115562,115563,115564)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115560,566),T17(115561,566),T17(115562,566),T17(115563,566),T17(115564,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115560,567),T17(115561,567),T17(115562,567),T17(115563,567),T17(115564,567))

	set = AddSet(50400,nil,RAID,16,"PR_TR_HEALER_16",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99024,99018,99017,99025,99023)
				AddVariant(60000,nil,RAID,set,"NORMAL",99591,99585,99584,99592,99590)
				AddVariant(60000,nil,RAID,set,"HEROIC",99117,99120,99119,99118,99131)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99366,99358,99357,99367,99365)
	
	set = AddSet(50400,nil,RAID,16,"PR_TR_CASTER_16",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99020,99005,99004,99021,99019)
				AddVariant(60000,nil,RAID,set,"NORMAL",99587,99628,99627,99588,99586)
				AddVariant(60000,nil,RAID,set,"HEROIC",99122,99111,99110,99123,99121)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99360,99363,99362,99361,99359)

	set = AddSet(50400,nil,RAID,15,"PR_TR_HEALER_15",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95926,95925,95927,95929,95928)
				AddVariant(50400,nil,RAID,set,"NORMAL",95296,95295,95297,95299,95298)
				AddVariant(50400,nil,RAID,set,"HEROIC",96670,96669,96671,96673,96672)
	
	set = AddSet(50400,nil,RAID,15,"PR_TR_CASTER_15",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95930,95931,95932,95933,95934)
				AddVariant(50400,nil,RAID,set,"NORMAL",95300,95301,95302,95303,95304)
				AddVariant(50400,nil,RAID,set,"HEROIC",96674,96675,96676,96677,96678)
	
	set = AddSet(50400,nil,RAID,14,"PR_TR_HEALER_14",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86702,86699,86700,86701,86703)
				AddVariant(50400,nil,RAID,set,"NORMAL",85362,85359,85360,85361,85363)
				AddVariant(50400,nil,RAID,set,"HEROIC",87115,87118,87117,87116,87114)

	set = AddSet(50400,nil,RAID,14,"PR_TR_CASTER_14",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86705,86708,86707,86706,86704)
				AddVariant(50400,nil,RAID,set,"NORMAL",85365,85368,85367,85366,85364)
				AddVariant(50400,nil,RAID,set,"HEROIC",87120,87123,87122,87121,87119)
	
	set = AddSet(50400,nil,RAID,13,"PR_TR_HEALER_13",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78795,78842,78823,78778,78814)
				AddVariant(50400,nil,RAID,set,"NORMAL",76358,76361,76360,76357,76359)
				AddVariant(50400,nil,RAID,set,"HEROIC",78700,78747,78728,78683,78719)

	set = AddSet(50400,nil,RAID,13,"PR_TR_CASTER_13",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78798,78845,78826,78777,78817)
				AddVariant(50400,nil,RAID,set,"NORMAL",76347,76344,76345,76348,76346)
				AddVariant(50400,nil,RAID,set,"HEROIC",78703,78750,78731,78682,78722)
	
	set = AddSet(50400,nil,RAID,12,"PR_TR_HEALER_12",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71272,71275,71274,71271,71273)
				AddVariant(50400,nil,RAID,set,"HEROIC",71528,71531,71530,71527,71529)

	set = AddSet(50400,nil,RAID,12,"PR_TR_CASTER_12",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71277,71280,71279,71276,71278)
				AddVariant(50400,nil,RAID,set,"HEROIC",71533,71536,71535,71532,71534)
	
	set = AddSet(50400,nil,RAID,11,"PR_TR_HEALER_11",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60258,60262,60261,60275,60259)
				AddVariant(50400,nil,RAID,set,"HEROIC",65229,65230,65231,65232,65233)

	set = AddSet(50400,nil,RAID,11,"PR_TR_CASTER_11",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60253,60254,60255,60256,60257)
				AddVariant(50400,nil,RAID,set,"HEROIC",65234,65235,65236,65237,65238)

	set = AddSet(50400,nil,RAID,10,"PR_TR_HEALER_10",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50765,50767,50768,50766,50769)
				AddVariant(50400,nil,RAID,set,"NORMAL",51178,51175,51176,51179,51177)
				AddVariant(50400,nil,RAID,set,"HEROIC",51261,51264,51263,51260,51262)

	set = AddSet(50400,nil,RAID,10,"PR_TR_CASTER_10",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50392,50396,50394,50391,50393)
				AddVariant(50400,nil,RAID,set,"NORMAL",51184,51182,51180,51183,51181)
				AddVariant(50400,nil,RAID,set,"HEROIC",51255,51257,51259,51256,51258)
	
	set = AddSet(50400,nil,RAID,9,"PR_TR_HEALER_A_09",PRIEST,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48035,48029,48031,48037,48033)
				AddVariant(50400,nil,RAID,set,"NORMAL",47984,47987,47986,47983,47985)
				AddVariant(50400,nil,RAID,set,"HEROIC",47914,47981,47936,47982,47980)
	
	set = AddSet(50400,nil,RAID,9,"PR_TR_CASTER_A_09",PRIEST,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48085,48082,48083,48086,48084)
				AddVariant(50400,nil,RAID,set,"NORMAL",48078,48081,48080,48077,48079)
				AddVariant(50400,nil,RAID,set,"HEROIC",48073,48076,48075,48072,48074)

	set = AddSet(50400,nil,RAID,9,"PR_TR_HEALER_H_09",PRIEST,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48058,48061,48060,48057,48059)
				AddVariant(50400,nil,RAID,set,"NORMAL",48065,48062,48063,48066,48064)
				AddVariant(50400,nil,RAID,set,"HEROIC",48068,48071,48070,48067,48069)
	
	set = AddSet(50400,nil,RAID,9,"PR_TR_CASTER_H_09",PRIEST,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48088,48091,48090,48087,48089)
				AddVariant(50400,nil,RAID,set,"NORMAL",48095,48092,48093,48096,48094)
				AddVariant(50400,nil,RAID,set,"HEROIC",48098,48101,48100,48097,48099)
	
	set = AddSet(50400,nil,RAID,8,"PR_TR_HEALER_08",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45386,45390,45389,45387,45388)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46197,46190,46193,46188,46195)

	set = AddSet(50400,nil,RAID,8,"PR_TR_CASTER_08",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45391,45393,45395,45392,45394)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46172,46165,46168,46163,46170)

	set = AddSet(50400,nil,RAID,7,"PR_TR_HEALER_07",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39514,39518,39515,39519,39517)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40447,40450,40449,40445,40448)

	set = AddSet(50400,nil,RAID,7,"PR_TR_CASTER_07",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39521,39529,39523,39530,39528)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40456,40459,40458,40454,40457)
	
	set = AddSet(50400,nil,RAID,6,"PR_TR_HEALER_06",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_HEALER_06",31063,31069,31066,34435,31060,34527,31068,34562)
	
	set = AddSet(50400,nil,RAID,6,"PR_TR_CASTER_06",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_CASTER_06",31064,31070,31065,34434,31061,34528,31067,34563)

	set = AddSet(50400,nil,RAID,5,"PR_TR_HEALER_05",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_HEALER_05",30152,30154,30150,30151,30153)
	
	set = AddSet(50400,nil,RAID,5,"PR_TR_CASTER_05",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_CASTER_05",30161,30163,30159,30160,30162)

	set = AddSet(50400,nil,RAID,4,"PR_TR_HEALER_04",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_HEALER_04",29049,29054,29050,29055,29053)
	
	set = AddSet(50400,nil,RAID,4,"PR_TR_CASTER_04",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_CASTER_04",29058,29060,29056,29057,29059)

	set = AddSet(50400,nil,RAID,3,"PR_TR_03",PRIEST,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_03",22514,22515,22512,22519,22517,22518,22513,22516,23061)

	set = AddSet(50400,nil,RAID,2,"PR_TR_02",PRIEST,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_02",16921,16924,16923,16926,16920,16925,16922,16919)

	set = AddSet(50400,nil,RAID,1,"PR_TR_01",PRIEST,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_01",16813,16816,16815,16819,16812,16817,16814,16811)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"PR_CD_90",PRIEST,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"PR_CD_90",90116,90113,90114,90112,90115,90110,90117,90111)
				
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"PR_DG_03",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_03",28413,27775,28230,27536,27875)
	
	set = AddSet(50400,nil,DUNGEON,31,"DG_CLOTH_03",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_CLOTH_03",28193,27796,28191,27465,27907)
	
	set = AddSet(50400,nil,DUNGEON,22,"PR_DG_AQ_2",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_AQ_2",21351,21348,21352,21350,21349)
	
	set = AddSet(50400,nil,DUNGEON,21,"PR_DG_AQ_1",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_AQ_1",21410,21412,21411)
	
	set = AddSet(50400,nil,DUNGEON,20,"PR_DG_02",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_02",22080,22082,22083,22079,22081,22078,22085,22084)
	
	set = AddSet(50400,nil,DUNGEON,1,"PR_DG_01",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_01",16693,16695,16690,16697,16692,16696,16694,16691)

	-- PvP
	set = AddSet(50400,nil,PVP,15,"PR_PVP_CASTER_15",PRIEST,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102621,102671,102707,102751,102622)
				AddVariant(50400,nil,PVP,set,"ELITE",103086,103083,103084,103085,103087,103135,103136)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_HEALER_15",PRIEST,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102615,102703,102704,102750,102681)
				AddVariant(50400,nil,PVP,set,"ELITE",103079,102993,102996,103078,103080,103081,103082)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_CASTER_15",PRIEST,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103467,103468,103469,103470,103471)
				AddVariant(50400,nil,PVP,set,"ELITE",103086,103083,103084,103085,103087,103135,103136)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_HEALER_15",PRIEST,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103462,103463,103464,103465,103466)
				AddVariant(50400,nil,PVP,set,"ELITE",103079,102993,102996,103078,103080,103081,103082)
	
end

local function AddRogueSets()
	local set = ""
	
	-- Legendary
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",102248)
	
	set = AddSet(50400,nil,LEGENDARY,85,"LG_ROGUE_85",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_ROGUE_85",77949,77950)
	
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",32837,32838)

	-- Raid
	set = AddSet(60000,nil,RAID,17,"RO_TR_17",ROGUE,MELEE,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115570,115571,115572,115573,115574)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115570,566),T17(115571,566),T17(115572,566),T17(115573,566),T17(115574,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115570,567),T17(115571,567),T17(115572,567),T17(115573,567),T17(115574,567))

	set = AddSet(50400,nil,RAID,16,"RO_TR_MELEE_16",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99008,99010,99006,99009,99007)
				AddVariant(60000,nil,RAID,set,"NORMAL",99631,99635,99629,99634,99630)
				AddVariant(60000,nil,RAID,set,"HEROIC",99114,99116,99112,99115,99113)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99348,99350,99356,99349,99355)

	set = AddSet(50400,nil,RAID,15,"RO_TR_MELEE_15",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",96680,96681,96682,96683,96679)
				AddVariant(50400,nil,RAID,set,"NORMAL",95306,95307,95308,95309,95305)
				AddVariant(50400,nil,RAID,set,"HEROIC",95936,95937,95938,95939,95935)

	set = AddSet(50400,nil,RAID,14,"RO_TR_MELEE_14",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86641,86639,86643,86640,86642)
				AddVariant(50400,nil,RAID,set,"NORMAL",85301,85299,85303,85300,85302)
				AddVariant(50400,nil,RAID,set,"HEROIC",86641,86639,86643,86640,86642)

	set = AddSet(50400,nil,RAID,13,"RO_TR_MELEE_13",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78794,78833,78759,78774,78803)
				AddVariant(50400,nil,RAID,set,"NORMAL",77025,77027,77023,77024,77026)
				AddVariant(50400,nil,RAID,set,"HEROIC",78699,78738,78664,78679,78708)

	set = AddSet(50400,nil,RAID,12,"RO_TR_MELEE_12",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71047,71049,71045,71046,71048)
				AddVariant(50400,nil,RAID,set,"HEROIC",71539,71541,71537,71538,71540)

	set = AddSet(50400,nil,RAID,11,"RO_TR_MELEE_11",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60298,60299,60300,60301,60302)
				AddVariant(50400,nil,RAID,set,"HEROIC",65239,65240,65241,65242,65243)

	set = AddSet(50400,nil,RAID,10,"RO_TR_MELEE_10",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50089,50105,50087,50088,50090)
				AddVariant(50400,nil,RAID,set,"NORMAL",51187,51185,51189,51188,51186)
				AddVariant(50400,nil,RAID,set,"HEROIC",51252,51254,51250,51251,51253)

	set = AddSet(50400,nil,RAID,9,"RO_TR_MELEE_A_09",ROGUE,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48218,48221,48219,48222,48220)
				AddVariant(50400,nil,RAID,set,"NORMAL",48225,48227,48223,48224,48226)
				AddVariant(50400,nil,RAID,set,"HEROIC",48230,48228,48232,48231,48229)
				
	set = AddSet(50400,nil,RAID,9,"RO_TR_MELEE_H_09",ROGUE,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48245,48247,48243,48244,48246)
				AddVariant(50400,nil,RAID,set,"NORMAL",48240,48238,48242,48241,48239)
				AddVariant(50400,nil,RAID,set,"HEROIC",48235,48237,48233,48234,48236)

	set = AddSet(50400,nil,RAID,8,"RO_TR_MELEE_08",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45398,45400,45396,45397,45399)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46125,46127,46123,46124,46126)

	set = AddSet(50400,nil,RAID,7,"RO_TR_MELEE_07",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39561,39565,39558,39560,39564)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40499,40502,40495,40496,40500)

	set = AddSet(50400,nil,RAID,6,"RO_TR_MELEE_06",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_MELEE_06",31027,31030,31028,34448,31026,34558,31029,34575)

	set = AddSet(50400,nil,RAID,5,"RO_TR_MELEE_05",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_MELEE_05",30146,30149,30144,30145,30148)

	set = AddSet(50400,nil,RAID,4,"RO_TR_MELEE_04",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_MELEE_04",29044,29047,29045,29048,29046)

	set = AddSet(50400,nil,RAID,3,"RO_TR_03",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_03",22478,22479,22476,22483,22481,22482,22477,22480,23060)

	set = AddSet(50400,nil,RAID,2,"RO_TR_02",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_02",16908,16832,16905,16911,16907,16910,16909,16906)

	set = AddSet(50400,nil,RAID,1,"RO_TR_01",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_01",16821,16823,16820,16825,16826,16827,16822,16824)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"RO_CD_90",ROGUE,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"RO_CD_90",90120,90125,90122,90126,90123,90119,90124,90121)
				
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"RO_DG_03",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_03",28414,27776,28204,27509,27908)
	
	set = AddSet(50400,nil,DUNGEON,31,"DG_LEATHER_03",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_LEATHER_03",28224,27797,28264,27531,27837)
	
	set = AddSet(50400,nil,DUNGEON,22,"RO_DG_AQ_2",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_AQ_2",21364,21360,21362,21361,21359)
	
	set = AddSet(50400,nil,DUNGEON,21,"RO_DG_AQ_1",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_AQ_1",21404,21406,21405)
	
	set = AddSet(50400,nil,DUNGEON,20,"RO_DG_02",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_02",22005,22008,22009,22004,22006,22002,22007,22003)
	
	set = AddSet(50400,nil,DUNGEON,10,"RO_DG_01",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_01",16707,16708,16721,16710,16712,16713,16709,16711)

	-- PvP
	set = AddSet(50400,nil,PVP,15,"RO_PVP_MELEE_15",ROGUE,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102663,102727,102730,102731,102710)
				AddVariant(50400,nil,PVP,set,"ELITE",103091,103088,103089,103090,103092,103093,103094)
				
	set = AddSet(50400,nil,PVP,15,"RO_PVP_MELEE_15",ROGUE,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103475,103476,103477,103478,103479)
				AddVariant(50400,nil,PVP,set,"ELITE",103091,103088,103089,103090,103092,103093,103094)
	
end

local function AddShamanSets()
	local set = ""
	
	-- Legendary
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",102246)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",102248)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",102247)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",46017)
	
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",17182)
	
	-- Raid	
	set = AddSet(60000,nil,RAID,17,"SH_TR_17",SHAMAN,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115575,115576,115577,115578,115579)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115575,566),T17(115576,566),T17(115577,566),T17(115578,566),T17(115579,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115575,567),T17(115576,567),T17(115577,567),T17(115578,567),T17(115579,567))
	
	set = AddSet(50400,nil,RAID,16,"SH_TR_CASTER_16",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99087,99088,99089,99090,99091)
				AddVariant(60000,nil,RAID,set,"NORMAL",99580,99645,99646,99647,99579)
				AddVariant(60000,nil,RAID,set,"HEROIC",99092,99093,99094,99095,99106)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99332,99333,99334,99344,99345)
	
	set = AddSet(50400,nil,RAID,16,"SH_TR_MELEE_16",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",98983,98977,98992,98984,98993)
				AddVariant(60000,nil,RAID,set,"NORMAL",99649,99663,99615,99650,99616)
  			AddVariant(60000,nil,RAID,set,"HEROIC",99103,99105,99101,99104,99102)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99341,99343,99347,99342,99340)
	
	set = AddSet(50400,nil,RAID,16,"SH_TR_HEALER_16",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",98989,98991,99011,98990,98988)
				AddVariant(60000,nil,RAID,set,"NORMAL",99612,99614,99636,99613,99611)
  			AddVariant(60000,nil,RAID,set,"HEROIC",99109,99100,99107,99099,99108)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99353,99346,99351,99354,99352)
	
	set = AddSet(50400,nil,RAID,15,"SH_TR_CASTER_15",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95950,95951,95952,95953,95954)
				AddVariant(50400,nil,RAID,set,"NORMAL",95320,95321,95322,95323,95324)
				AddVariant(50400,nil,RAID,set,"HEROIC",96694,96695,96696,96697,96698)

	set = AddSet(50400,nil,RAID,15,"SH_TR_MELEE_15",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95945,95946,95947,95948,95949)
				AddVariant(50400,nil,RAID,set,"NORMAL",95315,95316,95317,95318,95319)
				AddVariant(50400,nil,RAID,set,"HEROIC",96689,96690,96691,96692,96693)

	set = AddSet(50400,nil,RAID,15,"SH_TR_HEALER_15",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95942,95941,95943,95944,95940)
				AddVariant(50400,nil,RAID,set,"NORMAL",95312,95311,95313,95314,95310)
				AddVariant(50400,nil,RAID,set,"HEROIC",96686,96685,96687,96688,96684)
	
	set = AddSet(50400,nil,RAID,14,"SH_TR_CASTER_14",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86631,86633,86629,86630,86632)
				AddVariant(50400,nil,RAID,set,"NORMAL",85291,85289,85293,85290,85292)
				AddVariant(50400,nil,RAID,set,"HEROIC",87141,87143,87139,87140,87142)

	set = AddSet(50400,nil,RAID,14,"SH_TR_MELEE_14",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86626,86624,86628,86625,86627)
				AddVariant(50400,nil,RAID,set,"NORMAL",85286,85284,85288,85285,85287)
				AddVariant(50400,nil,RAID,set,"HEROIC",87136,87138,87134,87137,87135)

	set = AddSet(50400,nil,RAID,14,"SH_TR_HEALER_14",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86691,86689,86693,86690,86692)
				AddVariant(50400,nil,RAID,set,"NORMAL",85351,85349,85353,85350,85352)
				AddVariant(50400,nil,RAID,set,"HEROIC",87131,87133,87129,87132,87130)
	
	set = AddSet(50400,nil,RAID,13,"SH_TR_CASTER_13",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78780,78836,78818,78761,78806)
				AddVariant(50400,nil,RAID,set,"NORMAL",77037,77035,77039,77038,77036)
				AddVariant(50400,nil,RAID,set,"HEROIC",78685,78741,78723,78666,78711)

	set = AddSet(50400,nil,RAID,13,"SH_TR_MELEE_13",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78781,78828,78819,78762,78799)
				AddVariant(50400,nil,RAID,set,"NORMAL",77042,77044,77040,77041,77043)
				AddVariant(50400,nil,RAID,set,"HEROIC",78686,78733,78724,78667,78704)

	set = AddSet(50400,nil,RAID,13,"SH_TR_HEALER_13",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78786,78834,78820,78767,78813)
				AddVariant(50400,nil,RAID,set,"NORMAL",76758,76760,76756,76757,76759)
				AddVariant(50400,nil,RAID,set,"HEROIC",78691,78739,78725,78672,78718)

	set = AddSet(50400,nil,RAID,12,"SH_TR_CASTER_12",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71293,71295,71294,71292,71291)
				AddVariant(50400,nil,RAID,set,"HEROIC",71554,71556,71552,71553,71555)

	set = AddSet(50400,nil,RAID,12,"SH_TR_MELEE_12",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71303,71305,71301,71302,71304)
				AddVariant(50400,nil,RAID,set,"HEROIC",71549,71551,71547,71548,71550)

	set = AddSet(50400,nil,RAID,12,"SH_TR_HEALER_12",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71298,71300,71296,71297,71299)
				AddVariant(50400,nil,RAID,set,"HEROIC",71544,71546,71542,71543,71545)

	set = AddSet(50400,nil,RAID,11,"SH_TR_CASTER_11",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60314,60315,60316,60317,60313)
				AddVariant(50400,nil,RAID,set,"HEROIC",65254,65255,65256,65257,65258)

	set = AddSet(50400,nil,RAID,11,"SH_TR_MELEE_11",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60318,60319,60320,60321,60322)
				AddVariant(50400,nil,RAID,set,"HEROIC",65249,65250,65251,65252,65253)

	set = AddSet(50400,nil,RAID,11,"SH_TR_HEALER_11",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60308,60309,60310,60311,60312)
				AddVariant(50400,nil,RAID,set,"HEROIC",65244,65245,65246,65247,65248)
	
	set = AddSet(50400,nil,RAID,10,"SH_TR_CASTER_10",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50843,50845,50841,50842,50844)
				AddVariant(50400,nil,RAID,set,"NORMAL",51202,51204,51200,51201,51203)
				AddVariant(50400,nil,RAID,set,"HEROIC",51237,51235,51239,51238,51236)

	set = AddSet(50400,nil,RAID,10,"SH_TR_MELEE_10",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50832,50834,50830,50831,50833)
				AddVariant(50400,nil,RAID,set,"NORMAL",51197,51199,51195,51196,51198)
				AddVariant(50400,nil,RAID,set,"HEROIC",51242,51240,51244,51243,51241)

	set = AddSet(50400,nil,RAID,10,"SH_TR_HEALER_10",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50837,50839,50835,50836,50838)
				AddVariant(50400,nil,RAID,set,"NORMAL",51192,51194,51190,51191,51193)
				AddVariant(50400,nil,RAID,set,"HEROIC",51247,51245,51249,51248,51246)	
	
	set = AddSet(50400,nil,RAID,9,"SH_TR_CASTER_A_09",SHAMAN,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48313,48315,48310,48312,48314)
				AddVariant(50400,nil,RAID,set,"NORMAL",48318,48320,48316,48317,48319)
				AddVariant(50400,nil,RAID,set,"HEROIC",48323,48321,48325,48324,48322)

	set = AddSet(50400,nil,RAID,9,"SH_TR_MELEE_A_09",SHAMAN,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48343,48345,48341,48342,48344)
				AddVariant(50400,nil,RAID,set,"NORMAL",48348,48350,48346,48347,48349)
				AddVariant(50400,nil,RAID,set,"HEROIC",48353,48351,48355,48354,48352)

	set = AddSet(50400,nil,RAID,9,"SH_TR_HEALER_A_09",SHAMAN,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48280,48283,48281,48284,48282)
				AddVariant(50400,nil,RAID,set,"NORMAL",48287,48289,48285,48286,48288)
				AddVariant(50400,nil,RAID,set,"HEROIC",48292,48290,48294,48293,48291)

	set = AddSet(50400,nil,RAID,9,"SH_TR_CASTER_H_09",SHAMAN,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48338,48340,48336,48337,48339)
				AddVariant(50400,nil,RAID,set,"NORMAL",48333,48331,48335,48334,48332)
				AddVariant(50400,nil,RAID,set,"HEROIC",48328,48330,48326,48327,48329)

	set = AddSet(50400,nil,RAID,9,"SH_TR_MELEE_H_09",SHAMAN,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48368,48370,48366,48367,48369)
				AddVariant(50400,nil,RAID,set,"NORMAL",48363,48361,48365,48364,48362)
				AddVariant(50400,nil,RAID,set,"HEROIC",48358,48360,48356,48357,48359)

	set = AddSet(50400,nil,RAID,9,"SH_TR_HEALER_H_09",SHAMAN,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48297,48299,48295,48296,48298)
				AddVariant(50400,nil,RAID,set,"NORMAL",48302,48304,48300,48301,48303)
				AddVariant(50400,nil,RAID,set,"HEROIC",48307,48309,48305,48306,48308)
	
	set = AddSet(50400,nil,RAID,8,"SH_TR_CASTER_08",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45408,45410,45411,45406,45409)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46209,46211,46206,46207,46210)

	set = AddSet(50400,nil,RAID,8,"SH_TR_MELEE_08",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45412,45415,45413,45414,45416)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46212,46203,46205,46200,46208)

	set = AddSet(50400,nil,RAID,8,"SH_TR_HEALER_08",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45402,45404,45405,45401,45403)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46201,46204,46198,46199,46202)
	
	set = AddSet(50400,nil,RAID,7,"SH_TR_CASTER_07",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39594,39596,39592,39593,39595)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40516,40518,40514,40515,40517)

	set = AddSet(50400,nil,RAID,7,"SH_TR_MELEE_07",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39602,39604,39597,39601,39603)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40521,40524,40523,40520,40522)

	set = AddSet(50400,nil,RAID,7,"SH_TR_HEALER_07",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39583,39590,39588,39591,39589)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40510,40513,40508,40509,40512)
	
	set = AddSet(50400,nil,RAID,6,"SH_TR_CASTER_06",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_CASTER_06",31014,31023,31017,34437,31008,34542,31020,34566)
	
	set = AddSet(50400,nil,RAID,6,"SH_TR_MELEE_06",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_MELEE_06",31015,31024,31018,34439,31011,34545,31021,34567)
	
	set = AddSet(50400,nil,RAID,6,"SH_TR_HEALER_06",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_HEALER_06",31012,31022,31016,34438,31007,34543,31019,34565)
	
	set = AddSet(50400,nil,RAID,5,"SH_TR_CASTER_05",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_CASTER_05",30171,30173,30169,30170,30172)
	
	set = AddSet(50400,nil,RAID,5,"SH_TR_MELEE_05",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_MELEE_05",30190,30194,30185,30189,30192)
	
	set = AddSet(50400,nil,RAID,5,"SH_TR_HEALER_05",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_HEALER_05",30166,30168,30164,30165,30167)
	
	set = AddSet(50400,nil,RAID,4,"SH_TR_CASTER_04",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_CASTER_04",29035,29037,29033,29034,29036)
	
	set = AddSet(50400,nil,RAID,4,"SH_TR_MELEE_04",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_MELEE_04",29040,29043,29038,29039,29042)
	
	set = AddSet(50400,nil,RAID,4,"SH_TR_HEALER_04",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_HEALER_04",29028,29031,29029,29032,29030)
	
	set = AddSet(50400,nil,RAID,3,"SH_TR_03",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_03",22466,22467,22464,22471,22469,22470,22465,22468,23065)
	
	set = AddSet(50400,nil,RAID,2,"SH_TR_02",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_02",16947,16945,16950,16943,16948,16944,16946,16949)
	
	set = AddSet(50400,nil,RAID,1,"SH_TR_01",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_01",16842,16844,16841,16840,16839,16838,16843,16837)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,90,"SH_CD_90",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"SH_CD_90",90132,90134,90130,90127,90131,90128,90133,90129)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"SH_DG_03",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_03",28349,27802,28231,27510,27909)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_MAIL_03",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_MAIL_03",28192,27713,28401,27528,27936)
				
	set = AddSet(50400,nil,DUNGEON,22,"SH_DG_AQ_2",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_AQ_2",21374,21372,21375,21376,21373)
				
	set = AddSet(50400,nil,DUNGEON,21,"SH_DG_AQ_1",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_AQ_1",21398,21400,21399)
				
	set = AddSet(50400,nil,DUNGEON,20,"SH_DG_02",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_02",22097,22101,22102,22095,22099,22098,22100,22096)
				
	set = AddSet(50400,nil,DUNGEON,10,"SH_DG_01",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_01",16667,16669,16666,16671,16672,16673,16668,16670)
	
	-- PvP
	set = AddSet(50400,nil,PVP,15,"SH_PVP_CASTER_15",SHAMAN,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102637,102693,102743,102781,102692)
				AddVariant(50400,nil,PVP,set,"ELITE",103110,103097,102108,103109,103111,103112,103113)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_HEALER_15",SHAMAN,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102655,102718,102719,102774,102717)
				AddVariant(50400,nil,PVP,set,"ELITE",103099,103095,103096,103098,103100,103101,103102)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_MELEE_15",SHAMAN,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102629,102742,102759,102778,102714)
				AddVariant(50400,nil,PVP,set,"ELITE",103104,103034,103036,103103,103105,103106,103107)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_CASTER_15",SHAMAN,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103496,103497,103498,103499,103500)
				AddVariant(50400,nil,PVP,set,"ELITE",103110,103097,102108,103109,103111,103112,103113)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_HEALER_15",SHAMAN,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103485,103486,103487,103488,103489)
				AddVariant(50400,nil,PVP,set,"ELITE",103099,103095,103096,103098,103100,103101,103102)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_MELEE_15",SHAMAN,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103475,103476,103477,103478,103479)
				AddVariant(50400,nil,PVP,set,"ELITE",103104,103034,103036,103103,103105,103106,103107)
				
end

local function AddWarlockSets()
	local set = ""
	
  -- Legendaries
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",102246)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",71086)
	
	-- Tier 17
	set = AddSet(60000,nil,RAID,17,"WK_TR_17",WARLOCK,CASTER,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115585,115586,115587,115588,115589)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115585,566),T17(115586,566),T17(115587,566),T17(115588,566),T17(115589,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115585,567),T17(115586,567),T17(115587,567),T17(115588,567),T17(115589,567))
				
	-- Tier 16
	set = AddSet(50400,nil,RAID,16,"WK_TR_CASTER_16",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99053,99054,99055,99056,99045)
				AddVariant(60000,nil,RAID,set,"NORMAL",99567,99568,99569,99570,99601)
				AddVariant(60000,nil,RAID,set,"HEROIC",99096,99097,99098,99204,99205)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99424,99425,99426,99416,99417)
				
	-- Tier 15
	set = AddSet(50400,nil,RAID,15,"WK_TR_CASTER_15",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95981,95982,95983,95984,95985)
				AddVariant(50400,nil,RAID,set,"NORMAL",95325,95326,95327,95328,95329)
				AddVariant(50400,nil,RAID,set,"HEROIC",96725,96726,96727,96728,96729)
				
	-- Tier 14
	set = AddSet(50400,nil,RAID,14,"WK_TR_CASTER_14",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86710,86713,86712,86711,86709)
				AddVariant(50400,nil,RAID,set,"NORMAL",85370,85373,85372,85371,85369)
				AddVariant(50400,nil,RAID,set,"HEROIC",87188,87191,87190,87189,87187)
				
	-- Tier 13
	set = AddSet(50400,nil,RAID,13,"WK_TR_CASTER_13",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78797,78844,78825,78776,78816)
				AddVariant(50400,nil,RAID,set,"NORMAL",76342,76339,76340,76343,76341)
				AddVariant(50400,nil,RAID,set,"HEROIC",78702,78749,78730,78681,78721)
				
	-- Tier 12
	set = AddSet(50400,nil,RAID,12,"WK_TR_CASTER_12",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71282,71285,71284,71281,71283)
				AddVariant(50400,nil,RAID,set,"HEROIC",71595,71598,71597,71594,71596)
				
	-- Tier 11
	set = AddSet(50400,nil,RAID,11,"WK_TR_CASTER_11",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60249,60250,60251,60252,60248)
				AddVariant(50400,nil,RAID,set,"HEROIC",65259,65260,65261,65262,65263)
				
	-- Tier 10
	set = AddSet(50400,nil,RAID,10,"WK_TR_CASTER_10",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50241,50244,50243,50240,50242)
				AddVariant(50400,nil,RAID,set,"NORMAL",51208,51205,51206,51209,51207)
				AddVariant(50400,nil,RAID,set,"HEROIC",51231,51234,51233,51230,51232)
				
	-- Tier 9
	set = AddSet(50400,nil,RAID,9,"WK_TR_CASTER_A_09",WARLOCK,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",47784,47787,47786,47783,47785)
				AddVariant(50400,nil,RAID,set,"NORMAL",47778,47781,47779,47782,47780)
				AddVariant(50400,nil,RAID,set,"HEROIC",47789,47792,47791,47788,47790)
				
	set = AddSet(50400,nil,RAID,9,"WK_TR_CASTER_H_09",WARLOCK,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",47801,47798,47799,47802,47800)
				AddVariant(50400,nil,RAID,set,"NORMAL",47804,47807,47806,47803,47805)
				AddVariant(50400,nil,RAID,set,"HEROIC",47796,47793,47794,47797,47795)
				
	-- Tier 8
	set = AddSet(50400,nil,RAID,8,"WK_TR_CASTER_08",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45417,45422,45421,45419,45420)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46140,46136,46137,46135,46139)
				
	-- Tier 7
	set = AddSet(50400,nil,RAID,7,"WK_TR_CASTER_07",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39496,39499,39497,39500,39498)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40421,40424,40423,40420,40422)	
				
	-- Tier 6
	set = AddSet(50400,nil,RAID,6,"WK_TR_CASTER_06",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_CASTER_06",31051,31054,31052,34436,31050,34541,31053,34564)
				
	-- Tier 5
	set = AddSet(50400,nil,RAID,5,"WK_TR_CASTER_05",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_CASTER_05",30212,30215,30214,30211,30213)
				
	-- Tier 4
	set = AddSet(50400,nil,RAID,4,"WK_TR_CASTER_04",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_CASTER_04",28963,28967,28964,28968,28966)
				
	-- Tier 3
	set = AddSet(50400,nil,RAID,3,"WK_TR_03",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_03",22506,22507,22504,22511,22509,22510,22505,22508,23063)
				
	-- Tier 2
	set = AddSet(50400,nil,RAID,2,"WK_TR_02",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_02",16929,16932,16931,16934,16928,16933,16930,16927)
				
	-- Tier 1
	set = AddSet(50400,nil,RAID,1,"WK_TR_01",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_01",16808,16807,16809,16804,16805,16806,16810,16803)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"WK_CD_90",WARLOCK,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"WK_CD_90",90142,90138,90140,90139,90141,90136,90143,90137)
				
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"WK_DG_03",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_03",28415,27778,28232,27537,27948)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_CLOTH_03",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"DG_CLOTH_03",28193,27796,28191,27465,27907)
				
	set = AddSet(50400,nil,DUNGEON,22,"WK_DG_AQ_2",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_AQ_2",21334,21337,21336,21335,21338)
				
	set = AddSet(50400,nil,DUNGEON,21,"WK_DG_AQ_1",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_AQ_1",21416,21418,21417)
				
	set = AddSet(50400,nil,DUNGEON,20,"WK_DG_02",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_02",22074,22073,22075,22071,22077,22070,22072,22076)
				
	set = AddSet(50400,nil,DUNGEON,10,"WK_DG_01",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_01",16698,16701,16700,16703,16705,16702,16699,16704)

	-- PvP
	set = AddSet(50400,nil,PVP,15,"WK_PVP_CASTER_15",WARLOCK,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102661,102725,102726,102755,102682)
				AddVariant(50400,nil,PVP,set,"ELITE",103124,102992,102995,103123,103125,103126,103127)
				
	set = AddSet(50400,nil,PVP,15,"WK_PVP_CASTER_15",WARLOCK,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103520,103521,1035222,103523,103524)
				AddVariant(50400,nil,PVP,set,"ELITE",103124,102992,102995,103123,103125,103126,103127)
end

local function AddWarriorSets()
	local set = ""
	
  -- Legendaries
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_STR_90",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_STR_90",102249)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_STR_90",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_STR_90",102250)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",49623)
				
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",32837,32838)
				
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",17182)

	-- Tier 17
	set = AddSet(60000,nil,RAID,17,"WR_TR_17",WARRIOR,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"NORMAL",115580,115581,115582,115583,115584)
				AddVariant(60000,nil,RAID,set,"HEROIC",T17(115580,566),T17(115581,566),T17(115582,566),T17(115583,566),T17(115584,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",T17(115580,567),T17(115581,567),T17(115582,567),T17(115583,567),T17(115584,567))

	-- Tier 16
	set = AddSet(50400,nil,RAID,16,"WR_TR_MELEE_16",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99046,99036,99047,99035,99034)
				AddVariant(60000,nil,RAID,set,"NORMAL",99602,99561,99603,99560,99559)
				AddVariant(60000,nil,RAID,set,"HEROIC",99206,99200,99197,99199,99198)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99418,99414,99411,99413,99412)

	set = AddSet(50400,nil,RAID,16,"WR_TR_TANK_16",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",99032,99030,99037,99033,99038)
				AddVariant(60000,nil,RAID,set,"NORMAL",99557,99597,99562,99558,99563)
				AddVariant(60000,nil,RAID,set,"HEROIC",99203,99196,99201,99195,99202)
				AddVariant(60000,nil,RAID,set,"MYTHIC",99409,99407,99415,99410,99408)
	
	-- Tier 15
	set = AddSet(50400,nil,RAID,15,"WR_TR_MELEE_15",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95987,95988,95986,95989,95990)
				AddVariant(50400,nil,RAID,set,"NORMAL",95331,95332,95330,95333,95334)
				AddVariant(50400,nil,RAID,set,"HEROIC",96731,96732,96730,96733,96734)

	set = AddSet(50400,nil,RAID,15,"WR_TR_TANK_15",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",95991,95993,95992,95994,95995)
				AddVariant(50400,nil,RAID,set,"NORMAL",95335,95337,95336,95338,95339)
				AddVariant(50400,nil,RAID,set,"HEROIC",96735,96737,96736,96738,96739)
	
	-- Tier 14
	set = AddSet(50400,nil,RAID,14,"WR_TR_MELEE_14",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86673,86669,86672,86670,86671)
				AddVariant(50400,nil,RAID,set,"NORMAL",85333,85329,85332,85330,85331)
				AddVariant(50400,nil,RAID,set,"HEROIC",87192,87196,87193,87195,87194)

	set = AddSet(50400,nil,RAID,14,"WR_TR_TANK_14",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",86666,86664,86668,86665,86667)
				AddVariant(50400,nil,RAID,set,"NORMAL",85326,85324,85328,85325,85327)
				AddVariant(50400,nil,RAID,set,"HEROIC",87199,87201,87197,87200,87198)
	
	-- Tier 13
	set = AddSet(50400,nil,RAID,13,"WR_TR_MELEE_13",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78783,78830,78752,78763,78801)
				AddVariant(50400,nil,RAID,set,"NORMAL",76983,76987,76984,76985,76986)
				AddVariant(50400,nil,RAID,set,"HEROIC",78688,78735,78657,78668,78706)

	set = AddSet(50400,nil,RAID,13,"WR_TR_TANK_13",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",78784,78829,78753,78764,78800)
				AddVariant(50400,nil,RAID,set,"NORMAL",76990,76992,76988,76989,76991)
				AddVariant(50400,nil,RAID,set,"HEROIC",78689,78734,78658,78669,78705)
	
	-- Tier 12
	set = AddSet(50400,nil,RAID,12,"WR_TR_MELEE_12",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",71070,71072,71068,71069,71071)
				AddVariant(50400,nil,RAID,set,"HEROIC",71599,71603,71600,71601,71602)

	set = AddSet(50400,nil,RAID,12,"WR_TR_TANK_12",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",70944,70941,70945,70943,70942)
				AddVariant(50400,nil,RAID,set,"HEROIC",71606,71608,71604,71605,71607)	
	
	-- Tier 11
	set = AddSet(50400,nil,RAID,11,"WR_TR_MELEE_11",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60323,60324,60325,60326,60327)
				AddVariant(50400,nil,RAID,set,"HEROIC",65264,65265,65266,65267,65268)

	set = AddSet(50400,nil,RAID,11,"WR_TR_TANK_11",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60328,60329,60330,60331,60332)
				AddVariant(50400,nil,RAID,set,"HEROIC",65269,65270,65271,65272,65273)
	
	-- Tier 10
	set = AddSet(50400,nil,RAID,10,"WR_TR_MELEE_10",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50080,50082,50078,50079,50081)
				AddVariant(50400,nil,RAID,set,"NORMAL",51212,51210,51214,51213,51211)
				AddVariant(50400,nil,RAID,set,"HEROIC",51227,51229,51225,51226,51228)

	set = AddSet(50400,nil,RAID,10,"WR_TR_TANK_10",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",50848,50846,50850,50849,50847)
				AddVariant(50400,nil,RAID,set,"NORMAL",51218,51215,51219,51217,51216)
				AddVariant(50400,nil,RAID,set,"HEROIC",51221,51224,51220,51222,51223)

	-- Tier 9
	set = AddSet(50400,nil,RAID,9,"WR_TR_MELEE_A_09",WARRIOR,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48371,48374,48372,48375,48373)
				AddVariant(50400,nil,RAID,set,"NORMAL",48378,48380,48376,48377,48379)
				AddVariant(50400,nil,RAID,set,"HEROIC",48383,48381,48385,48384,48382)
	
	set = AddSet(50400,nil,RAID,9,"WR_TR_TANK_A_09",WARRIOR,TANK,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48429,48448,48436,48449,48445)
				AddVariant(50400,nil,RAID,set,"NORMAL",48430,48454,48450,48452,48446)
				AddVariant(50400,nil,RAID,set,"HEROIC",48433,48455,48451,48453,48447)

	set = AddSet(50400,nil,RAID,9,"WR_TR_MELEE_H_09",WARRIOR,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48388,48390,48386,48387,48389)
				AddVariant(50400,nil,RAID,set,"NORMAL",48393,48395,48391,48392,48394)
				AddVariant(50400,nil,RAID,set,"HEROIC",48398,48400,48396,48397,48399)

	set = AddSet(50400,nil,RAID,9,"WR_TR_TANK_H_09",WARRIOR,TANK,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",48458,48460,48456,48457,48459)
				AddVariant(50400,nil,RAID,set,"NORMAL",48463,48465,48461,48462,48464)
				AddVariant(50400,nil,RAID,set,"HEROIC",48468,48470,48466,48467,48469)
	
	-- Tier 8
	set = AddSet(50400,nil,RAID,8,"WR_TR_MELEE_08",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45431,45433,45429,45430,45432)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46151,46149,46146,46148,46150)

	set = AddSet(50400,nil,RAID,8,"WR_TR_TANK_08",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",45425,45428,45424,45426,45427)
				AddVariant(50400,nil,RAID,set,"25PLAYER",46166,46167,46164,46162,46169)

	-- Tier 7
	set = AddSet(50400,nil,RAID,7,"WR_TR_MELEE_07",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39605,39608,39606,39609,39607)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40528,40530,40525,40527,40529)
	
	set = AddSet(50400,nil,RAID,7,"WR_TR_TANK_07",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"10PLAYER",39610,39613,39611,39622,39612)
				AddVariant(50400,nil,RAID,set,"25PLAYER",40546,40548,40544,40545,40547)
	
	-- Tier 6
	set = AddSet(50400,nil,RAID,6,"WR_TR_MELEE_06",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_MELEE_06",30972,30979,30975,34441,30969,34546,30977,34569)
				
	set = AddSet(50400,nil,RAID,6,"WR_TR_TANK_06",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_TANK_06",30974,30980,30976,34442,30970,34547,30978,34568)
	
	-- Tier 5
	set = AddSet(50400,nil,RAID,5,"WR_TR_MELEE_05",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_MELEE_05",30120,30122,30118,30119,30121)
				
	set = AddSet(50400,nil,RAID,5,"WR_TR_TANK_05",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_TANK_05",30115,30117,30113,30114,30116)
	
	-- Tier 4
	set = AddSet(50400,nil,RAID,4,"WR_TR_MELEE_04",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_MELEE_04",29021,29023,29019,29020,29022)
				
	set = AddSet(50400,nil,RAID,4,"WR_TR_TANK_04",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_TANK_04",29011,29016,29012,29017,29015)
	
	-- Tier 3
	set = AddSet(50400,nil,RAID,3,"WR_TR_03",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_03",22418,22419,22416,22423,22421,22422,22417,22420,23059)
	
	-- Tier 2
	set = AddSet(50400,nil,RAID,2,"WR_TR_02",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_02",16963,16961,16966,16959,16964,16960,16962,16965)
	
	-- Tier 1
	set = AddSet(50400,nil,RAID,1,"WR_TR_01",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_01",16866,16868,16865,16861,16863,16864,16867,16862)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"WR_CD_90",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"WR_CD_90",90151,90153,90149,90154,90150,90147,90152,90148)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"WR_DG_03",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_03",28350,27803,28205,27475,27977)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_PLATE_03",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_PLATE_03",28225,27771,28403,27497,27870)
	
	set = AddSet(50400,nil,DUNGEON,22,"WR_DG_AQ_2",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_AQ_2",21331,21329,21332,21330,21333)
	
	set = AddSet(50400,nil,DUNGEON,21,"WR_DG_AQ_1",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_AQ_1",21392,21394,21393)
	
	set = AddSet(50400,nil,DUNGEON,20,"WR_DG_02",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_02",21999,22001,21997,21996,21998,21994,22000,21995)
	
	set = AddSet(50400,nil,DUNGEON,10,"WR_DG_01",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_01",16731,16733,16730,16735,16737,16736,16732,16734)
	
	-- PvP
	set = AddSet(50400,nil,PVP,15,"WR_PVP_MELEE_15",WARRIOR,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",102618,102685,102728,102732,102619)
				AddVariant(50400,nil,PVP,set,"ELITE",103129,103074,103075,103128,103130,103131,103132)
				
	set = AddSet(50400,nil,PVP,15,"WR_PVP_MELEE_15",WARRIOR,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",103525,103526,103527,103528,103529)
				AddVariant(50400,nil,PVP,set,"ELITE",103129,103074,103075,103128,103130,103131,103132)
				
end

local function AddHolidaySets()
	local set = ""
	
	set = AddSet(50400,nil,HOLIDAY,1103271,"HO_FESTIVE_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",21157)
				AddVariant(50400,nil,HOLIDAY,set,"PINK",21538)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",21539)
				AddVariant(50400,nil,HOLIDAY,set,"RED",21154)
				
	set = AddSet(50400,nil,HOLIDAY,1103272,"HO_FESTIVE_SUIT",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",21541)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",21544)
				AddVariant(50400,nil,HOLIDAY,set,"TEAL",21543)
				AddVariant(50400,nil,HOLIDAY,set,"RED",21542)
				
	set = AddSet(50400,nil,HOLIDAY,1203351,"HO_LOVELY_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",22279)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",22278)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",22280)
				AddVariant(50400,nil,HOLIDAY,set,"RED",22276)
				
	set = AddSet(50400,nil,HOLIDAY,1203352,"HO_DINNER_SUIT",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",22281)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",22282)
				AddVariant(50400,nil,HOLIDAY,set,"RED",22277)
				
	set = AddSet(50400,nil,HOLIDAY,1401811,"HO_ELEGANT_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"HO_ELEGANT_DRESS",19028)
				
	set = AddSet(50400,nil,HOLIDAY,1401812,"HO_TUXEDO",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",6833,6835)
				
	set = AddSet(50400,nil,HOLIDAY,1603411,"HO_MIDSUMMER_REVELER",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"RED",23324,34685,34683)
				
	set = AddSet(50400,nil,HOLIDAY,1903721,"HO_BREWFEST_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",33968,33863,33966)
				AddVariant(50400,nil,HOLIDAY,set,"BROWN",33864,33863,33966)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",33967,33863,33966)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",33969,33863,33966)
				
	set = AddSet(50400,nil,HOLIDAY,1903722,"HO_BREWFEST_REGALIA",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",33968,33862,33868)
				AddVariant(50400,nil,HOLIDAY,set,"BROWN",33864,33862,33868)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",33967,33862,33868)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",33969,33862,33868)
	
	set = AddSet(50400,nil,HOLIDAY,2003241,"HO_HALLOWED_HELM",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",33292)
	
	set = AddSet(50400,nil,HOLIDAY,2003242,"HO_HORSEMANS_HOOD",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"90",87569)
				AddVariant(50400,nil,HOLIDAY,set,"100",117355)
	
	set = AddSet(50400,nil,HOLIDAY,2003242,"HO_HORSEMANS_HOOD",PALADIN,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"90",87569)
				AddVariant(50400,nil,HOLIDAY,set,"100",117355)
	
	set = AddSet(50400,nil,HOLIDAY,2003242,"HO_HORSEMANS_HOOD",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"90",87569)
				AddVariant(50400,nil,HOLIDAY,set,"100",117355)
	
	set = AddSet(50400,nil,HOLIDAY,2003243,"HO_HORSEMANS_SLICER",ROGUE,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"90",87570)
				AddVariant(50400,nil,HOLIDAY,set,"100",117356)
	
	set = AddSet(50400,nil,HOLIDAY,2104041,"HO_PILGRIMS_ATTIRE",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",46723,46800,44788)
				AddVariant(50400,nil,HOLIDAY,set,"FINE",116401,46800,44788)
	
	set = AddSet(50400,nil,HOLIDAY,2104042,"HO_PILGRIMS_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",46723,44785,44788)
				AddVariant(50400,nil,HOLIDAY,set,"FINE",116401,44785,44788)
	
	set = AddSet(50400,nil,HOLIDAY,2201411,"HO_WINTER_GARB",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",21525,34087,34086)
				AddVariant(50400,nil,HOLIDAY,set,"RED",21524,34085,34086)
			
end

--
-- Setup Database
--

function SetCollectorSetupDB(release, override)
	if SetCollectorDB == nil or SetCollectorDB.version ~= DB_VERSION or override == true then
		
		-- Clear previous DB to avoid duplicate entries
		--SetCollectorDB = { version = DB_VERSION, release = release }
		
		CreateCollections(DB_VERSION, release)
	
		-- Add Sets to Collections
		AddDeathKnightSets()
		AddDruidSets()
		AddHunterSets()
		AddMageSets()
		AddMonkSets()
		AddPaladinSets()
		AddPriestSets()
		AddRogueSets()
		AddShamanSets()
		AddWarlockSets()
		AddWarriorSets()
		AddHolidaySets()
		
		if (override == true) then print(_L["DB_UPGRADED"]) end
	end
end

function SetCollectorSetupCharacterDB(class, release, override)
	if SetCollectorCharacterDB == nil or override == true then
		SetCollectorCharacterDB = { version = DB_VERSION, release = release, minimap = { hide = false }, Sets = { }, Items = { } }
		for i=1, #SetCollectorDB do
			for j in pairs(SetCollectorDB[i].Sets) do
				if ( SetCollectorDB[i].Sets[j].Class == class or SetCollectorDB[i].Sets[j].Class == ANY.Description ) then
					-- Set Info
					SetCollectorCharacterDB.Sets[j] = { Favorite = false, Tracking = false }
					-- Item Info
					for k=1, #SetCollectorDB[i].Sets[j].Variants do
						for l=1, #SetCollectorDB[i].Sets[j].Variants[k].Items do
							local itemID = SetCollectorDB[i].Sets[j].Variants[k].Items[l]
							local itemCheck = itemID
							SetCollectorCharacterDB.Items[itemID] = { Count = 0 }
							local count = SetCollectorCharacterDB.Items[itemID].Count
						end
					end
				end
			end
		end
		if (override == true) then print("|cffff6666".._L["CHAR_DB_UPGRADED"].."|r") end
		
	elseif SetCollectorCharacterDB.release < 30 then
		SetCollectorCharacterDB = { version = DB_VERSION, release = release, minimap = { hide = false }, Sets = { }, Items = { } }
		for i=1, #SetCollectorDB do
			for j in pairs(SetCollectorDB[i].Sets) do
				if ( SetCollectorDB[i].Sets[j].Class == class or SetCollectorDB[i].Sets[j].Class == ANY.Description ) then
					-- Set Info
					SetCollectorCharacterDB.Sets[j] = { Favorite = false, Tracking = false }
					-- Item Info
					for k=1, #SetCollectorDB[i].Sets[j].Variants do
						for l=1, #SetCollectorDB[i].Sets[j].Variants[k].Items do
							local itemID = SetCollectorDB[i].Sets[j].Variants[k].Items[l]
							SetCollectorCharacterDB.Items[itemID] = { Count = 0 }
						end
					end
				end
			end
		end
		print("|cff6666ff".._L["CHAR_DB_UPGRADED"].."|r")
		
	elseif SetCollectorCharacterDB.version ~= DB_VERSION or SetCollectorCharacterDB.release < release then
		SetCollectorCharacterDB.version = DB_VERSION
		SetCollectorCharacterDB.release = release
		local added = 0
		for i=1, #SetCollectorDB do
			for j in pairs(SetCollectorDB[i].Sets) do
				if ( SetCollectorDB[i].Sets[j].Class == class or SetCollectorDB[i].Sets[j].Class == ANY.Description ) then
					-- Set Info
					if ( not SetCollectorCharacterDB.Sets[j] ) then
						SetCollectorCharacterDB.Sets[j] = { Favorite = false, Tracking = false }
						added = added + 1
					end
					-- Item Info
					for k=1, #SetCollectorDB[i].Sets[j].Variants do
						for l=1, #SetCollectorDB[i].Sets[j].Variants[k].Items do
							local itemID = SetCollectorDB[i].Sets[j].Variants[k].Items[l]
							if ( not SetCollectorCharacterDB.Items[itemID] ) then
								SetCollectorCharacterDB.Items[itemID] = { Count = 0 }
								added = added + 1
							end
						end
					end
				end
			end
		end
		if ( added > 0 ) then
			print("|cff66ff66".._L["CHAR_DB_UPGRADED"].."|r")
		end
	end
	
end